@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -13,11 +13,15 @@
 
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
+
 #include <isc/base64.h>
 #include <isc/buffer.h>
 #include <isc/event.h>
 #include <isc/file.h>
 #include <isc/mem.h>
+#include <isc/mutex.h>
 #include <isc/net.h>
 #include <isc/netaddr.h>
 #include <isc/random.h>
@@ -64,7 +68,7 @@ typedef ISC_LIST(controllistener_t) controllistenerlist_t;
 
 struct controlkey {
 	char *				keyname;
-	isc_uint32_t			algorithm;
+	uint32_t			algorithm;
 	isc_region_t			secret;
 	ISC_LINK(controlkey_t)		link;
 };
@@ -72,12 +76,12 @@ struct controlkey {
 struct controlconnection {
 	isc_socket_t *			sock;
 	isccc_ccmsg_t			ccmsg;
-	isc_boolean_t			ccmsg_valid;
-	isc_boolean_t			sending;
+	bool				ccmsg_valid;
+	bool				sending;
 	isc_timer_t *			timer;
 	isc_buffer_t *			buffer;
 	controllistener_t *		listener;
-	isc_uint32_t			nonce;
+	uint32_t			nonce;
 	ISC_LINK(controlconnection_t)	link;
 };
 
@@ -88,22 +92,23 @@ struct controllistener {
 	isc_sockaddr_t			address;
 	isc_socket_t *			sock;
 	dns_acl_t *			acl;
-	isc_boolean_t			listening;
-	isc_boolean_t			exiting;
+	bool				listening;
+	bool				exiting;
 	controlkeylist_t		keys;
 	controlconnectionlist_t		connections;
 	isc_sockettype_t		type;
-	isc_uint32_t			perm;
-	isc_uint32_t			owner;
-	isc_uint32_t			group;
-	isc_boolean_t			readonly;
+	uint32_t			perm;
+	uint32_t			owner;
+	uint32_t			group;
+	bool				readonly;
 	ISC_LINK(controllistener_t)	link;
 };
 
 struct ns_controls {
 	ns_server_t			*server;
 	controllistenerlist_t 		listeners;
-	isc_boolean_t			shuttingdown;
+	bool				shuttingdown;
+	isc_mutex_t			symtab_lock;
 	isccc_symtab_t			*symtab;
 };
 
@@ -201,8 +206,8 @@ shutdown_listener(controllistener_t *listener) {
 			      NS_LOGMODULE_CONTROL, ISC_LOG_NOTICE,
 			      "stopping command channel on %s", socktext);
 		if (listener->type == isc_sockettype_unix)
-			isc_socket_cleanunix(&listener->address, ISC_TRUE);
-		listener->exiting = ISC_TRUE;
+			isc_socket_cleanunix(&listener->address, true);
+		listener->exiting = true;
 	}
 
 	for (conn = ISC_LIST_HEAD(listener->connections);
@@ -220,7 +225,7 @@ shutdown_listener(controllistener_t *listener) {
 	maybe_free_listener(listener);
 }
 
-static isc_boolean_t
+static bool
 address_ok(isc_sockaddr_t *sockaddr, dns_acl_t *acl) {
 	isc_netaddr_t netaddr;
 	isc_result_t result;
@@ -232,9 +237,9 @@ address_ok(isc_sockaddr_t *sockaddr, dns_acl_t *acl) {
 			       &ns_g_server->aclenv, &match, NULL);
 
 	if (result != ISC_R_SUCCESS || match <= 0)
-		return (ISC_FALSE);
+		return (false);
 	else
-		return (ISC_TRUE);
+		return (true);
 }
 
 static isc_result_t
@@ -248,7 +253,7 @@ control_accept(controllistener_t *listener) {
 				 "isc_socket_accept() failed: %s",
 				 isc_result_totext(result));
 	else
-		listener->listening = ISC_TRUE;
+		listener->listening = true;
 	return (result);
 }
 
@@ -281,7 +286,7 @@ control_senddone(isc_task_t *task, isc_event_t *event) {
 
 	UNUSED(task);
 
-	conn->sending = ISC_FALSE;
+	conn->sending = false;
 
 	if (sevent->result != ISC_R_SUCCESS &&
 	    sevent->result != ISC_R_CANCELED)
@@ -327,7 +332,7 @@ control_recvmessage(isc_task_t *task, isc_event_t *event) {
 	controlkey_t *key;
 	isccc_sexpr_t *request = NULL;
 	isccc_sexpr_t *response = NULL;
-	isc_uint32_t algorithm;
+	uint32_t algorithm;
 	isccc_region_t secret;
 	isc_stdtime_t now;
 	isc_buffer_t b;
@@ -338,7 +343,7 @@ control_recvmessage(isc_task_t *task, isc_event_t *event) {
 	isccc_sexpr_t *_ctrl;
 	isccc_time_t sent;
 	isccc_time_t exp;
-	isc_uint32_t nonce;
+	uint32_t nonce;
 	isccc_sexpr_t *data;
 
 	REQUIRE(event->ev_type == ISCCC_EVENT_CCMSG);
@@ -431,8 +436,10 @@ control_recvmessage(isc_task_t *task, isc_event_t *event) {
 	/*
 	 * Duplicate suppression (required for UDP).
 	 */
+	LOCK(&listener->controls->symtab_lock);
 	isccc_cc_cleansymtab(listener->controls->symtab, now);
 	result = isccc_cc_checkdup(listener->controls->symtab, request, now);
+	UNLOCK(&listener->controls->symtab_lock);
 	if (result != ISC_R_SUCCESS) {
 		if (result == ISC_R_EXISTS)
 			result = ISCCC_R_DUPLICATE;
@@ -516,7 +523,7 @@ control_recvmessage(isc_task_t *task, isc_event_t *event) {
 	result = isc_socket_send(conn->sock, &r, task, control_senddone, conn);
 	if (result != ISC_R_SUCCESS)
 		goto cleanup_response;
-	conn->sending = ISC_TRUE;
+	conn->sending = true;
 
 	isc_mem_put(listener->mctx, secret.rstart, REGION_SIZE(secret));
 	isccc_sexpr_free(&request);
@@ -536,7 +543,7 @@ control_recvmessage(isc_task_t *task, isc_event_t *event) {
  cleanup:
 	isc_socket_detach(&conn->sock);
 	isccc_ccmsg_invalidate(&conn->ccmsg);
-	conn->ccmsg_valid = ISC_FALSE;
+	conn->ccmsg_valid = false;
 	maybe_free_connection(conn);
 	maybe_free_listener(listener);
 }
@@ -569,8 +576,8 @@ newconnection(controllistener_t *listener, isc_socket_t *sock) {
 	/* Set a 32 KiB upper limit on incoming message. */
 	isccc_ccmsg_setmaxsize(&conn->ccmsg, 32768);
 
-	conn->ccmsg_valid = ISC_TRUE;
-	conn->sending = ISC_FALSE;
+	conn->ccmsg_valid = true;
+	conn->sending = false;
 	conn->buffer = NULL;
 	conn->timer = NULL;
 	isc_interval_set(&interval, 60, 0);
@@ -617,7 +624,7 @@ control_newconn(isc_task_t *task, isc_event_t *event) {
 
 	UNUSED(task);
 
-	listener->listening = ISC_FALSE;
+	listener->listening = false;
 
 	if (nevent->result != ISC_R_SUCCESS) {
 		if (nevent->result == ISC_R_CANCELED) {
@@ -681,7 +688,7 @@ controls_shutdown(ns_controls_t *controls) {
 void
 ns_controls_shutdown(ns_controls_t *controls) {
 	controls_shutdown(controls);
-	controls->shuttingdown = ISC_TRUE;
+	controls->shuttingdown = true;
 }
 
 static isc_result_t
@@ -1085,7 +1092,7 @@ update_listener(ns_controls_t *cp, controllistener_t **listenerp,
 			      socktext, isc_result_totext(result));
 
 	if (result == ISC_R_SUCCESS && type == isc_sockettype_unix) {
-		isc_uint32_t perm, owner, group;
+		uint32_t perm, owner, group;
 		perm  = cfg_obj_asuint32(cfg_tuple_get(control, "perm"));
 		owner = cfg_obj_asuint32(cfg_tuple_get(control, "owner"));
 		group = cfg_obj_asuint32(cfg_tuple_get(control, "group"));
@@ -1132,14 +1139,14 @@ add_listener(ns_controls_t *cp, controllistener_t **listenerp,
 		listener->task = cp->server->task;
 		listener->address = *addr;
 		listener->sock = NULL;
-		listener->listening = ISC_FALSE;
-		listener->exiting = ISC_FALSE;
+		listener->listening = false;
+		listener->exiting = false;
 		listener->acl = NULL;
 		listener->type = type;
 		listener->perm = 0;
 		listener->owner = 0;
 		listener->group = 0;
-		listener->readonly = ISC_FALSE;
+		listener->readonly = false;
 		ISC_LINK_INIT(listener, link);
 		ISC_LIST_INIT(listener->keys);
 		ISC_LIST_INIT(listener->connections);
@@ -1202,7 +1209,7 @@ add_listener(ns_controls_t *cp, controllistener_t **listenerp,
 	}
 
 	if (result == ISC_R_SUCCESS && type == isc_sockettype_unix)
-		isc_socket_cleanunix(&listener->address, ISC_FALSE);
+		isc_socket_cleanunix(&listener->address, false);
 
 	if (result == ISC_R_SUCCESS)
 		result = isc_socket_create(ns_g_socketmgr,
@@ -1213,7 +1220,7 @@ add_listener(ns_controls_t *cp, controllistener_t **listenerp,
 
 #ifndef ISC_ALLOW_MAPPED
 	if (result == ISC_R_SUCCESS)
-		isc_socket_ipv6only(listener->sock, ISC_TRUE);
+		isc_socket_ipv6only(listener->sock, true);
 #endif
 
 	if (result == ISC_R_SUCCESS)
@@ -1244,7 +1251,7 @@ add_listener(ns_controls_t *cp, controllistener_t **listenerp,
 
 	} else {
 		if (listener != NULL) {
-			listener->exiting = ISC_TRUE;
+			listener->exiting = true;
 			free_listener(listener);
 		}
 
@@ -1500,17 +1507,31 @@ ns_controls_create(ns_server_t *server, ns_controls_t **ctrlsp) {
 	isc_result_t result;
 	ns_controls_t *controls = isc_mem_get(mctx, sizeof(*controls));
 
-	if (controls == NULL)
+	if (controls == NULL) {
 		return (ISC_R_NOMEMORY);
-	controls->server = server;
+	}
+
+	*controls = (ns_controls_t){
+		.server = server,
+	};
+
 	ISC_LIST_INIT(controls->listeners);
-	controls->shuttingdown = ISC_FALSE;
-	controls->symtab = NULL;
-	result = isccc_cc_createsymtab(&controls->symtab);
+
+	result = isc_mutex_init(&controls->symtab_lock);
 	if (result != ISC_R_SUCCESS) {
 		isc_mem_put(server->mctx, controls, sizeof(*controls));
 		return (result);
 	}
+
+	LOCK(&controls->symtab_lock);
+	result = isccc_cc_createsymtab(&controls->symtab);
+	UNLOCK(&controls->symtab_lock);
+
+	if (result != ISC_R_SUCCESS) {
+		isc_mutex_destroy(&controls->symtab_lock);
+		isc_mem_put(server->mctx, controls, sizeof(*controls));
+		return (result);
+	}
 	*ctrlsp = controls;
 	return (ISC_R_SUCCESS);
 }
@@ -1521,7 +1542,10 @@ ns_controls_destroy(ns_controls_t **ctrlsp) {
 
 	REQUIRE(ISC_LIST_EMPTY(controls->listeners));
 
+	LOCK(&controls->symtab_lock);
 	isccc_symtab_destroy(&controls->symtab);
+	UNLOCK(&controls->symtab_lock);
+	isc_mutex_destroy(&controls->symtab_lock);
 	isc_mem_put(controls->server->mctx, controls, sizeof(*controls));
 	*ctrlsp = NULL;
 }
