@@ -1,14 +1,19 @@
 /*
- * Copyright (C) 2013, 2015-2017  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
 /*! \file */
 #include <config.h>
 
+#include <stdbool.h>
+
 #include <isc/entropy.h>
 #include <isc/hash.h>
 #include <isc/log.h>
@@ -37,7 +42,7 @@ isc_mem_t *mctx = NULL;
 isc_log_t *lctx = NULL;
 isc_entropy_t *ectx = NULL;
 
-static isc_boolean_t hash_active = ISC_FALSE, dst_active = ISC_FALSE;
+static bool hash_active = false, dst_active = false;
 
 /*
  * Logging categories: this needs to match the list in bin/named/log.c.
@@ -60,8 +65,7 @@ loadzone(dns_db_t **db, const char *origin, const char *filename) {
 	dns_fixedname_t fixed;
 	dns_name_t *name;
 
-	dns_fixedname_init(&fixed);
-	name = dns_fixedname_name(&fixed);
+	name = dns_fixedname_initname(&fixed);
 
 	result = dns_name_fromstring(name, origin, 0, NULL);
 	if (result != ISC_R_SUCCESS)
@@ -99,10 +103,10 @@ main(int argc, char **argv) {
 	CHECK(isc_entropy_create(mctx, &ectx));
 
 	CHECK(isc_hash_create(mctx, ectx, DNS_NAME_MAXWIRE));
-	hash_active = ISC_TRUE;
+	hash_active = true;
 
 	CHECK(dst_lib_init(mctx, ectx, ISC_ENTROPY_BLOCKING));
-	dst_active = ISC_TRUE;
+	dst_active = true;
 
 	CHECK(isc_log_create(mctx, &lctx, &logconfig));
 	isc_log_registercategories(lctx, categories);
@@ -148,11 +152,11 @@ main(int argc, char **argv) {
 		isc_log_destroy(&lctx);
 	if (dst_active) {
 		dst_lib_destroy();
-		dst_active = ISC_FALSE;
+		dst_active = false;
 	}
 	if (hash_active) {
 		isc_hash_destroy();
-		hash_active = ISC_FALSE;
+		hash_active = false;
 	}
 	if (ectx != NULL)
 		isc_entropy_detach(&ectx);
@@ -161,4 +165,3 @@ main(int argc, char **argv) {
 
 	return(result != ISC_R_SUCCESS ? 1 : 0);
 }
-
