@@ -1,21 +1,17 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
 #include <config.h>
 
+#include <stdbool.h>
 #include <stdlib.h>
 
 #include <unistd.h>		/* XXX */
@@ -58,7 +54,7 @@ use(dst_key_t *key, isc_mem_t *mctx) {
 	isc_buffer_usedregion(&databuf, &datareg);
 
 	ret = dst_context_create3(key, mctx,
-				  DNS_LOGCATEGORY_GENERAL, ISC_TRUE, &ctx);
+				  DNS_LOGCATEGORY_GENERAL, true, &ctx);
 	if (ret != ISC_R_SUCCESS) {
 		printf("contextcreate(%u) returned: %s\n", dst_key_alg(key),
 		       isc_result_totext(ret));
@@ -79,7 +75,7 @@ use(dst_key_t *key, isc_mem_t *mctx) {
 	isc_buffer_forward(&sigbuf, 1);
 	isc_buffer_remainingregion(&sigbuf, &sigreg);
 	ret = dst_context_create3(key, mctx,
-				  DNS_LOGCATEGORY_GENERAL, ISC_FALSE, &ctx);
+				  DNS_LOGCATEGORY_GENERAL, false, &ctx);
 	if (ret != ISC_R_SUCCESS) {
 		printf("contextcreate(%u) returned: %s\n", dst_key_alg(key),
 		       isc_result_totext(ret));
@@ -106,7 +102,7 @@ dns(dst_key_t *key, isc_mem_t *mctx) {
 	isc_region_t r1, r2;
 	dst_key_t *newkey = NULL;
 	isc_result_t ret;
-	isc_boolean_t match;
+	bool match;
 
 	isc_buffer_init(&buf1, buffer1, sizeof(buffer1));
 	ret = dst_key_todns(key, &buf1);
@@ -128,8 +124,8 @@ dns(dst_key_t *key, isc_mem_t *mctx) {
 		return;
 	isc_buffer_usedregion(&buf1, &r1);
 	isc_buffer_usedregion(&buf2, &r2);
-	match = ISC_TF(r1.length == r2.length &&
-		       memcmp(r1.base, r2.base, r1.length) == 0);
+	match = (r1.length == r2.length &&
+		 memcmp(r1.base, r2.base, r1.length) == 0);
 	printf("compare(%u): %s\n", dst_key_alg(key),
 	       match ? "true" : "false");
 	dst_key_free(&newkey);
@@ -261,8 +257,7 @@ main(void) {
 		return (1);
 	dst_lib_init(mctx, ectx, ISC_ENTROPY_BLOCKING|ISC_ENTROPY_GOODONLY);
 
-	dns_fixedname_init(&fname);
-	name = dns_fixedname_name(&fname);
+	name = dns_fixedname_initname(&fname);
 	isc_buffer_constinit(&b, "test.", 5);
 	isc_buffer_add(&b, 5);
 	result = dns_name_fromtext(name, &b, NULL, 0, NULL);
