@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -11,6 +11,7 @@
 
 #include <config.h>
 
+#include <stdbool.h>
 #include <stdlib.h>
 
 #include <isc/commandline.h>
@@ -45,7 +46,7 @@ print_name(dns_name_t *name) {
 
 	isc_buffer_init(&source, s, sizeof(s));
 	if (dns_name_countlabels(name) > 0)
-		result = dns_name_totext(name, ISC_FALSE, &source);
+		result = dns_name_totext(name, false, &source);
 	else
 		result = ISC_R_SUCCESS;
 	if (result == ISC_R_SUCCESS) {
@@ -68,14 +69,14 @@ main(int argc, char *argv[]) {
 	dns_name_t *name, *origin, *comp, *down;
 	unsigned int downcase = 0;
 	size_t len;
-	isc_boolean_t quiet = ISC_FALSE;
-	isc_boolean_t concatenate = ISC_FALSE;
-	isc_boolean_t got_name = ISC_FALSE;
-	isc_boolean_t check_absolute = ISC_FALSE;
-	isc_boolean_t check_wildcard = ISC_FALSE;
-	isc_boolean_t test_downcase = ISC_FALSE;
-	isc_boolean_t inplace = ISC_FALSE;
-	isc_boolean_t want_split = ISC_FALSE;
+	bool quiet = false;
+	bool concatenate = false;
+	bool got_name = false;
+	bool check_absolute = false;
+	bool check_wildcard = false;
+	bool test_downcase = false;
+	bool inplace = false;
+	bool want_split = false;
 	unsigned int labels, split_label = 0;
 	dns_fixedname_t fprefix, fsuffix;
 	dns_name_t *prefix, *suffix;
@@ -84,26 +85,26 @@ main(int argc, char *argv[]) {
 	while ((ch = isc_commandline_parse(argc, argv, "acdiqs:w")) != -1) {
 		switch (ch) {
 		case 'a':
-			check_absolute = ISC_TRUE;
+			check_absolute = true;
 			break;
 		case 'c':
-			concatenate = ISC_TRUE;
+			concatenate = true;
 			break;
 		case 'd':
-			test_downcase = ISC_TRUE;
+			test_downcase = true;
 			break;
 		case 'i':
-			inplace = ISC_TRUE;
+			inplace = true;
 			break;
 		case 'q':
-			quiet = ISC_TRUE;
+			quiet = true;
 			break;
 		case 's':
-			want_split = ISC_TRUE;
+			want_split = true;
 			split_label = atoi(isc_commandline_argument);
 			break;
 		case 'w':
-			check_wildcard = ISC_TRUE;
+			check_wildcard = true;
 			break;
 		}
 	}
@@ -239,13 +240,13 @@ main(int argc, char *argv[]) {
 				} else
 					printf("%s\n",
 					       dns_result_totext(result));
-				got_name = ISC_FALSE;
+				got_name = false;
 			} else
-				got_name = ISC_TRUE;
+				got_name = true;
 		}
 		isc_buffer_init(&source, s, sizeof(s));
 		if (dns_name_countlabels(name) > 0)
-			result = dns_name_totext(name, ISC_FALSE, &source);
+			result = dns_name_totext(name, false, &source);
 		else
 			result = ISC_R_SUCCESS;
 		if (result == ISC_R_SUCCESS) {
