@@ -1,16 +1,17 @@
 #!/bin/sh
 #
-# Copyright (C) 2010, 2012-2017  Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
-
-# $Id: clean.sh,v 1.3 2010/09/15 03:32:34 marka Exp $
+# file, you can obtain one at https://mozilla.org/MPL/2.0/.
+#
+# See the COPYRIGHT file distributed with this work for additional
+# information regarding copyright ownership.
 
 rm -f dig.out.*
 rm -f rndc.out*
-rm -f ns2/named.conf
+rm -f */named.conf
 rm -f */named.memstats
 rm -f ns2/*.nzf
 rm -f ns2/*.nzf~
