@@ -1,11 +1,9 @@
 #!/bin/sh
-
+#
 # Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 #
-# SPDX-License-Identifier: MPL-2.0
-#
 # This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0.  If a copy of the MPL was not distributed with this
+# License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, you can obtain one at https://mozilla.org/MPL/2.0/.
 #
 # See the COPYRIGHT file distributed with this work for additional
@@ -20,4 +18,4 @@ rm -f dig.out*
 rm -f */named.conf
 rm -f */named.run
 rm -f */named.memstats
-rm -f ns*/managed-keys.bind*
+rm -f ns*/named.lock
