@@ -883,9 +883,6 @@ dlz_create(const char *dlzname, unsigned int argc, char *argv[],
 	char *tmp = NULL;
 	char *endp;
 	const char *helper_name;
-#if SQLITE3_VERSION_ID >= 50000
-        my_bool auto_reconnect = 1;
-#endif
 #if PTHREADS
 	int dbcount;
 	int i, ret;
