@@ -1,13 +1,14 @@
 /*
- * Copyright (C) 1999-2009, 2011-2016  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id$ */
-
 #ifndef DNS_DB_H
 #define DNS_DB_H 1
 
@@ -45,6 +46,10 @@
  ***** Imports
  *****/
 
+#include <inttypes.h>
+#include <stdbool.h>
+
+#include <isc/deprecated.h>
 #include <isc/lang.h>
 #include <isc/magic.h>
 #include <isc/ondestroy.h>
@@ -85,9 +90,9 @@ typedef struct dns_dbmethods {
 					 dns_dbversion_t **targetp);
 	void		(*closeversion)(dns_db_t *db,
 					dns_dbversion_t **versionp,
-					isc_boolean_t commit);
+					bool commit);
 	isc_result_t	(*findnode)(dns_db_t *db, dns_name_t *name,
-				    isc_boolean_t create,
+				    bool create,
 				    dns_dbnode_t **nodep);
 	isc_result_t	(*find)(dns_db_t *db, dns_name_t *name,
 				dns_dbversion_t *version,
@@ -139,10 +144,10 @@ typedef struct dns_dbmethods {
 					  dns_dbversion_t *version,
 					  dns_rdatatype_t type,
 					  dns_rdatatype_t covers);
-	isc_boolean_t	(*issecure)(dns_db_t *db);
+	bool	(*issecure)(dns_db_t *db);
 	unsigned int	(*nodecount)(dns_db_t *db);
-	isc_boolean_t	(*ispersistent)(dns_db_t *db);
-	void		(*overmem)(dns_db_t *db, isc_boolean_t overmem);
+	bool	(*ispersistent)(dns_db_t *db);
+	void		(*overmem)(dns_db_t *db, bool overmem);
 	void		(*settask)(dns_db_t *db, isc_task_t *);
 	isc_result_t	(*getoriginnode)(dns_db_t *db, dns_dbnode_t **nodep);
 	void		(*transfernode)(dns_db_t *db, dns_dbnode_t **sourcep,
@@ -150,12 +155,12 @@ typedef struct dns_dbmethods {
 	isc_result_t    (*getnsec3parameters)(dns_db_t *db,
 					      dns_dbversion_t *version,
 					      dns_hash_t *hash,
-					      isc_uint8_t *flags,
-					      isc_uint16_t *iterations,
+					      uint8_t *flags,
+					      uint16_t *iterations,
 					      unsigned char *salt,
 					      size_t *salt_len);
 	isc_result_t    (*findnsec3node)(dns_db_t *db, dns_name_t *name,
-					 isc_boolean_t create,
+					 bool create,
 					 dns_dbnode_t **nodep);
 	isc_result_t	(*setsigningtime)(dns_db_t *db,
 					  dns_rdataset_t *rdataset,
@@ -165,13 +170,13 @@ typedef struct dns_dbmethods {
 					  dns_name_t *name);
 	void		(*resigned)(dns_db_t *db, dns_rdataset_t *rdataset,
 					   dns_dbversion_t *version);
-	isc_boolean_t	(*isdnssec)(dns_db_t *db);
+	bool	(*isdnssec)(dns_db_t *db);
 	dns_stats_t	*(*getrrsetstats)(dns_db_t *db);
 	void		(*rpz_attach)(dns_db_t *db, dns_rpz_zones_t *rpzs,
 				      dns_rpz_num_t rpz_num);
 	isc_result_t	(*rpz_ready)(dns_db_t *db);
 	isc_result_t	(*findnodeext)(dns_db_t *db, dns_name_t *name,
-				     isc_boolean_t create,
+				     bool create,
 				     dns_clientinfomethods_t *methods,
 				     dns_clientinfo_t *clientinfo,
 				     dns_dbnode_t **nodep);
@@ -188,6 +193,8 @@ typedef struct dns_dbmethods {
 	size_t		(*hashsize)(dns_db_t *db);
 	isc_result_t	(*nodefullname)(dns_db_t *db, dns_dbnode_t *node,
 					dns_name_t *name);
+	isc_result_t	(*getsize)(dns_db_t *db, dns_dbversion_t *version,
+				   uint64_t *records, uint64_t *bytes);
 } dns_dbmethods_t;
 
 typedef isc_result_t
@@ -215,7 +222,7 @@ struct dns_db {
 	unsigned int				magic;
 	unsigned int				impmagic;
 	dns_dbmethods_t *			methods;
-	isc_uint16_t				attributes;
+	uint16_t				attributes;
 	dns_rdataclass_t			rdclass;
 	dns_name_t				origin;
 	isc_ondestroy_t				ondest;
@@ -365,7 +372,7 @@ dns_db_ondestroy(dns_db_t *db, isc_task_t *task, isc_event_t **eventp);
  * sent to the task.
  */
 
-isc_boolean_t
+bool
 dns_db_iscache(dns_db_t *db);
 /*%<
  * Does 'db' have cache semantics?
@@ -375,11 +382,11 @@ dns_db_iscache(dns_db_t *db);
  * \li	'db' is a valid database.
  *
  * Returns:
- * \li	#ISC_TRUE	'db' has cache semantics
- * \li	#ISC_FALSE	otherwise
+ * \li	#true	'db' has cache semantics
+ * \li	#false	otherwise
  */
 
-isc_boolean_t
+bool
 dns_db_iszone(dns_db_t *db);
 /*%<
  * Does 'db' have zone semantics?
@@ -389,11 +396,11 @@ dns_db_iszone(dns_db_t *db);
  * \li	'db' is a valid database.
  *
  * Returns:
- * \li	#ISC_TRUE	'db' has zone semantics
- * \li	#ISC_FALSE	otherwise
+ * \li	#true	'db' has zone semantics
+ * \li	#false	otherwise
  */
 
-isc_boolean_t
+bool
 dns_db_isstub(dns_db_t *db);
 /*%<
  * Does 'db' have stub semantics?
@@ -403,11 +410,11 @@ dns_db_isstub(dns_db_t *db);
  * \li	'db' is a valid database.
  *
  * Returns:
- * \li	#ISC_TRUE	'db' has zone semantics
- * \li	#ISC_FALSE	otherwise
+ * \li	#true	'db' has zone semantics
+ * \li	#false	otherwise
  */
 
-isc_boolean_t
+bool
 dns_db_issecure(dns_db_t *db);
 /*%<
  * Is 'db' secure?
@@ -417,11 +424,11 @@ dns_db_issecure(dns_db_t *db);
  * \li	'db' is a valid database with zone semantics.
  *
  * Returns:
- * \li	#ISC_TRUE	'db' is secure.
- * \li	#ISC_FALSE	'db' is not secure.
+ * \li	#true	'db' is secure.
+ * \li	#false	'db' is not secure.
  */
 
-isc_boolean_t
+bool
 dns_db_isdnssec(dns_db_t *db);
 /*%<
  * Is 'db' secure or partially secure?
@@ -431,8 +438,8 @@ dns_db_isdnssec(dns_db_t *db);
  * \li	'db' is a valid database with zone semantics.
  *
  * Returns:
- * \li	#ISC_TRUE	'db' is secure or is partially.
- * \li	#ISC_FALSE	'db' is not secure.
+ * \li	#true	'db' is secure or is partially.
+ * \li	#false	'db' is not secure.
  */
 
 dns_name_t *
@@ -669,11 +676,11 @@ dns_db_attachversion(dns_db_t *db, dns_dbversion_t *source,
 
 void
 dns_db_closeversion(dns_db_t *db, dns_dbversion_t **versionp,
-		    isc_boolean_t commit);
+		    bool commit);
 /*%<
  * Close version '*versionp'.
  *
- * Note: if '*versionp' is a read-write version and 'commit' is ISC_TRUE,
+ * Note: if '*versionp' is a read-write version and 'commit' is true,
  * then all changes made in the version will take effect, otherwise they
  * will be rolled back.  The value of 'commit' is ignored for read-only
  * versions.
@@ -692,7 +699,7 @@ dns_db_closeversion(dns_db_t *db, dns_dbversion_t **versionp,
  *
  * \li	*versionp == NULL
  *
- * \li	If *versionp is a read-write version, and commit is ISC_TRUE, then
+ * \li	If *versionp is a read-write version, and commit is true, then
  *	the version will become the current version.  If !commit, then all
  *	changes made in the version will be undone, and the version will
  *	not become the current version.
@@ -703,11 +710,11 @@ dns_db_closeversion(dns_db_t *db, dns_dbversion_t **versionp,
  ***/
 
 isc_result_t
-dns_db_findnode(dns_db_t *db, dns_name_t *name, isc_boolean_t create,
+dns_db_findnode(dns_db_t *db, dns_name_t *name, bool create,
 		dns_dbnode_t **nodep);
 
 isc_result_t
-dns_db_findnodeext(dns_db_t *db, dns_name_t *name, isc_boolean_t create,
+dns_db_findnodeext(dns_db_t *db, dns_name_t *name, bool create,
 		   dns_clientinfomethods_t *methods,
 		   dns_clientinfo_t *clientinfo, dns_dbnode_t **nodep);
 /*%<
@@ -715,11 +722,11 @@ dns_db_findnodeext(dns_db_t *db, dns_name_t *name, isc_boolean_t create,
  *
  * dns_db_findnodeext() (findnode extended) also accepts parameters
  * 'methods' and 'clientinfo', which, when provided, enable the database to
- * retreive information about the client from the caller, and modify its
+ * retrieve information about the client from the caller, and modify its
  * response on the basis of that information.
  *
  * Notes:
- * \li	If 'create' is ISC_TRUE and no node with name 'name' exists, then
+ * \li	If 'create' is true and no node with name 'name' exists, then
  *	such a node will be created.
  *
  * \li	This routine is for finding or creating a node with the specified
@@ -743,7 +750,7 @@ dns_db_findnodeext(dns_db_t *db, dns_name_t *name, isc_boolean_t create,
  *
  * \li	#ISC_R_SUCCESS
  * \li	#ISC_R_NOTFOUND			If !create and name not found.
- * \li	#ISC_R_NOMEMORY			Can only happen if create is ISC_TRUE.
+ * \li	#ISC_R_NOMEMORY			Can only happen if create is true.
  *
  * \li	Other results are possible, depending upon the database
  *	implementation used.
@@ -765,7 +772,7 @@ dns_db_findext(dns_db_t *db, dns_name_t *name, dns_dbversion_t *version,
  * Find the best match for 'name' and 'type' in version 'version' of 'db'.
  *
  * dns_db_findext() (find extended) also accepts parameters 'methods'
- * and 'clientinfo', which when provided enable the database to retreive
+ * and 'clientinfo', which when provided enable the database to retrieve
  * information about the client from the caller, and modify its response
  * on the basis of this information.
  *
@@ -854,14 +861,6 @@ dns_db_findext(dns_db_t *db, dns_name_t *name, dns_dbversion_t *version,
  *	\li	#ISC_R_SUCCESS			The desired node and type were
  *						found.
  *
- *	\li	#DNS_R_WILDCARD			The desired node and type were
- *						found after performing
- *						wildcard matching.  This is
- *						only returned if the
- *						#DNS_DBFIND_INDICATEWILD
- *						option is set; otherwise
- *						#ISC_R_SUCCESS is returned.
- *
  *	\li	#DNS_R_GLUE			The desired node and type were
  *						found, but are glue.  This
  *						result can only occur if
@@ -1355,7 +1354,7 @@ dns_db_deleterdataset(dns_db_t *db, dns_dbnode_t *node,
  */
 
 isc_result_t
-dns_db_getsoaserial(dns_db_t *db, dns_dbversion_t *ver, isc_uint32_t *serialp);
+dns_db_getsoaserial(dns_db_t *db, dns_dbversion_t *ver, uint32_t *serialp);
 /*%<
  * Get the current SOA serial number from a zone database.
  *
@@ -1365,7 +1364,7 @@ dns_db_getsoaserial(dns_db_t *db, dns_dbversion_t *ver, isc_uint32_t *serialp);
  */
 
 void
-dns_db_overmem(dns_db_t *db, isc_boolean_t overmem);
+dns_db_overmem(dns_db_t *db, bool overmem);
 /*%<
  * Enable / disable aggressive cache cleaning.
  */
@@ -1408,7 +1407,7 @@ dns_db_settask(dns_db_t *db, isc_task_t *task);
  * \li	'task' to be valid or NULL.
  */
 
-isc_boolean_t
+bool
 dns_db_ispersistent(dns_db_t *db);
 /*%<
  * Is 'db' persistent?  A persistent database does not need to be loaded
@@ -1419,8 +1418,8 @@ dns_db_ispersistent(dns_db_t *db);
  * \li	'db' is a valid database.
  *
  * Returns:
- * \li	#ISC_TRUE	'db' is persistent.
- * \li	#ISC_FALSE	'db' is not persistent.
+ * \li	#true	'db' is persistent.
+ * \li	#false	'db' is not persistent.
  */
 
 isc_result_t
@@ -1486,8 +1485,8 @@ dns_db_getoriginnode(dns_db_t *db, dns_dbnode_t **nodep);
 
 isc_result_t
 dns_db_getnsec3parameters(dns_db_t *db, dns_dbversion_t *version,
-			  dns_hash_t *hash, isc_uint8_t *flags,
-			  isc_uint16_t *interations,
+			  dns_hash_t *hash, uint8_t *flags,
+			  uint16_t *iterations,
 			  unsigned char *salt, size_t *salt_length);
 /*%<
  * Get the NSEC3 parameters that are associated with this zone.
@@ -1501,14 +1500,32 @@ dns_db_getnsec3parameters(dns_db_t *db, dns_dbversion_t *version,
  *			  or this zone does not have NSEC3 records.
  */
 
+isc_result_t
+dns_db_getsize(dns_db_t *db, dns_dbversion_t *version, uint64_t *records,
+	       uint64_t *bytes);
+/*%<
+ * Get the number of records in the given version of the database as well
+ * as the number bytes used to store those records.
+ *
+ * Requires:
+ * \li	'db' is a valid zone database.
+ * \li	'version' is NULL or a valid version.
+ * \li	'records' is NULL or a pointer to return the record count in.
+ * \li	'bytes' is NULL or a pointer to return the byte count in.
+ *
+ * Returns:
+ * \li	#ISC_R_SUCCESS
+ * \li	#ISC_R_NOTIMPLEMENTED
+ */
+
 isc_result_t
 dns_db_findnsec3node(dns_db_t *db, dns_name_t *name,
-		     isc_boolean_t create, dns_dbnode_t **nodep);
+		     bool create, dns_dbnode_t **nodep);
 /*%<
  * Find the NSEC3 node with name 'name'.
  *
  * Notes:
- * \li	If 'create' is ISC_TRUE and no node with name 'name' exists, then
+ * \li	If 'create' is true and no node with name 'name' exists, then
  *	such a node will be created.
  *
  * Requires:
@@ -1527,7 +1544,7 @@ dns_db_findnsec3node(dns_db_t *db, dns_name_t *name,
  *
  * \li	#ISC_R_SUCCESS
  * \li	#ISC_R_NOTFOUND			If !create and name not found.
- * \li	#ISC_R_NOMEMORY			Can only happen if create is ISC_TRUE.
+ * \li	#ISC_R_NOMEMORY			Can only happen if create is true.
  *
  * \li	Other results are possible, depending upon the database
  *	implementation used.
