@@ -1,17 +1,12 @@
 /*
  * Portions Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
 /*
@@ -49,7 +44,6 @@
  * USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id$ */
 
 /*! \file dns/dlz.h */
 
@@ -83,6 +77,8 @@
  ***** Imports
  *****/
 
+#include <stdbool.h>
+
 #include <dns/clientinfo.h>
 #include <dns/name.h>
 #include <dns/types.h>
@@ -180,7 +176,7 @@ typedef isc_result_t
  */
 
 
-typedef isc_boolean_t (*dns_dlzssumatch_t)(dns_name_t *signer,
+typedef bool (*dns_dlzssumatch_t)(dns_name_t *signer,
 					   dns_name_t *name,
 					   isc_netaddr_t *tcpaddr,
 					   dns_rdatatype_t type,
@@ -221,7 +217,7 @@ struct dns_dlzdb {
 	dns_dlzimplementation_t	*implementation;
 	void			*dbdata;
 	dlzconfigure_callback_t configure_callback;
-	isc_boolean_t		search;
+	bool		search;
 	char			*dlzname;
 	ISC_LINK(dns_dlzdb_t)	link;
 	dns_ssutable_t 		*ssutable;
@@ -330,12 +326,12 @@ dns_dlzconfigure(dns_view_t *view, dns_dlzdb_t *dlzdb,
  * call a DLZ drivers configure method, if supplied
  */
 
-isc_boolean_t
+bool
 dns_dlz_ssumatch(dns_dlzdb_t *dlzdatabase,
 		  dns_name_t *signer, dns_name_t *name, isc_netaddr_t *tcpaddr,
 		  dns_rdatatype_t type, const dst_key_t *key);
 /*%<
- * call a DLZ drivers ssumatch method, if supplied. Otherwise return ISC_FALSE
+ * call a DLZ drivers ssumatch method, if supplied. Otherwise return false
  */
 
 ISC_LANG_ENDDECLS
