@@ -3,14 +3,12 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
  */
 
-/* $Id: rriterator.h,v 1.4 2011/11/01 23:47:00 tbox Exp $ */
-
 #ifndef DNS_RRITERATOR_H
 #define DNS_RRITERATOR_H 1
 
@@ -27,6 +25,8 @@
  ***** Imports
  *****/
 
+#include <inttypes.h>
+
 #include <isc/lang.h>
 #include <isc/magic.h>
 #include <isc/ondestroy.h>
@@ -131,7 +131,7 @@ dns_rriterator_next(dns_rriterator_t *it);
 
 void
 dns_rriterator_current(dns_rriterator_t *it, dns_name_t **name,
-			  isc_uint32_t *ttl, dns_rdataset_t **rdataset,
+			  uint32_t *ttl, dns_rdataset_t **rdataset,
 			  dns_rdata_t **rdata);
 /*%<
  * Make '*name' refer to the current name.  If 'rdataset' is not NULL,
