@@ -1,20 +1,14 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id: soa.h,v 1.12 2009/09/10 01:47:09 each Exp $ */
 
 #ifndef DNS_SOA_H
 #define DNS_SOA_H 1
@@ -32,6 +26,8 @@
  *** Imports
  ***/
 
+#include <inttypes.h>
+
 #include <isc/lang.h>
 #include <isc/types.h>
 
@@ -44,9 +40,9 @@ ISC_LANG_BEGINDECLS
 isc_result_t
 dns_soa_buildrdata(dns_name_t *origin, dns_name_t *contact,
 		   dns_rdataclass_t rdclass,
-		   isc_uint32_t serial, isc_uint32_t refresh,
-		   isc_uint32_t retry, isc_uint32_t expire,
-		   isc_uint32_t minimum, unsigned char *buffer,
+		   uint32_t serial, uint32_t refresh,
+		   uint32_t retry, uint32_t expire,
+		   uint32_t minimum, unsigned char *buffer,
 		   dns_rdata_t *rdata);
 /*%<
  * Build the rdata of an SOA record.
@@ -61,15 +57,15 @@ dns_soa_buildrdata(dns_name_t *origin, dns_name_t *contact,
  *  			refers to 'buffer'.
  */
 
-isc_uint32_t
+uint32_t
 dns_soa_getserial(dns_rdata_t *rdata);
-isc_uint32_t
+uint32_t
 dns_soa_getrefresh(dns_rdata_t *rdata);
-isc_uint32_t
+uint32_t
 dns_soa_getretry(dns_rdata_t *rdata);
-isc_uint32_t
+uint32_t
 dns_soa_getexpire(dns_rdata_t *rdata);
-isc_uint32_t
+uint32_t
 dns_soa_getminimum(dns_rdata_t *rdata);
 /*
  * Extract an integer field from the rdata of a SOA record.
@@ -79,15 +75,15 @@ dns_soa_getminimum(dns_rdata_t *rdata);
  */
 
 void
-dns_soa_setserial(isc_uint32_t val, dns_rdata_t *rdata);
+dns_soa_setserial(uint32_t val, dns_rdata_t *rdata);
 void
-dns_soa_setrefresh(isc_uint32_t val, dns_rdata_t *rdata);
+dns_soa_setrefresh(uint32_t val, dns_rdata_t *rdata);
 void
-dns_soa_setretry(isc_uint32_t val, dns_rdata_t *rdata);
+dns_soa_setretry(uint32_t val, dns_rdata_t *rdata);
 void
-dns_soa_setexpire(isc_uint32_t val, dns_rdata_t *rdata);
+dns_soa_setexpire(uint32_t val, dns_rdata_t *rdata);
 void
-dns_soa_setminimum(isc_uint32_t val, dns_rdata_t *rdata);
+dns_soa_setminimum(uint32_t val, dns_rdata_t *rdata);
 /*
  * Change an integer field of a SOA record by modifying the
  * rdata in-place.
