@@ -1,8 +1,6 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * SPDX-License-Identifier: MPL-2.0
- *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at https://mozilla.org/MPL/2.0/.
@@ -11,8 +9,11 @@
  * information regarding copyright ownership.
  */
 
+
 /*! \file */
 
+#include <config.h>
+
 #include <inttypes.h>
 #include <stdbool.h>
 
@@ -30,25 +31,25 @@
 #define DNS_NCACHE_RDATA 100U
 
 /*
- * The format of an ncache rdata is a sequence of zero or more records
- * of the following format:
+ * The format of an ncache rdata is a sequence of zero or more records of
+ * the following format:
  *
  *	owner name
  *	type
  *	trust
  *	rdata count
- *	rdata length			These two occur 'rdata
- *	rdata				count' times.
+ *		rdata length			These two occur 'rdata count'
+ *		rdata				times.
  *
  */
 
 static isc_result_t
 addoptout(dns_message_t *message, dns_db_t *cache, dns_dbnode_t *node,
-	  dns_rdatatype_t covers, isc_stdtime_t now, dns_ttl_t minttl,
-	  dns_ttl_t maxttl, bool optout, bool secure,
+	  dns_rdatatype_t covers, isc_stdtime_t now, dns_ttl_t maxttl,
+	  bool optout, bool secure,
 	  dns_rdataset_t *addedrdataset);
 
-static isc_result_t
+static inline isc_result_t
 copy_rdataset(dns_rdataset_t *rdataset, isc_buffer_t *buffer) {
 	isc_result_t result;
 	unsigned int count;
@@ -59,9 +60,8 @@ copy_rdataset(dns_rdataset_t *rdataset, isc_buffer_t *buffer) {
 	 * Copy the rdataset count to the buffer.
 	 */
 	isc_buffer_availableregion(buffer, &ar);
-	if (ar.length < 2) {
+	if (ar.length < 2)
 		return (ISC_R_NOSPACE);
-	}
 	count = dns_rdataset_count(rdataset);
 	INSIST(count <= 65535);
 	isc_buffer_putuint16(buffer, (uint16_t)count);
@@ -72,9 +72,8 @@ copy_rdataset(dns_rdataset_t *rdataset, isc_buffer_t *buffer) {
 		dns_rdata_toregion(&rdata, &r);
 		INSIST(r.length <= 65535);
 		isc_buffer_availableregion(buffer, &ar);
-		if (ar.length < 2) {
+		if (ar.length < 2)
 			return (ISC_R_NOSPACE);
-		}
 		/*
 		 * Copy the rdata length to the buffer.
 		 */
@@ -83,41 +82,42 @@ copy_rdataset(dns_rdataset_t *rdataset, isc_buffer_t *buffer) {
 		 * Copy the rdata to the buffer.
 		 */
 		result = isc_buffer_copyregion(buffer, &r);
-		if (result != ISC_R_SUCCESS) {
+		if (result != ISC_R_SUCCESS)
 			return (result);
-		}
 		dns_rdata_reset(&rdata);
 		result = dns_rdataset_next(rdataset);
 	}
-	if (result != ISC_R_NOMORE) {
+	if (result != ISC_R_NOMORE)
 		return (result);
-	}
 
 	return (ISC_R_SUCCESS);
 }
 
 isc_result_t
 dns_ncache_add(dns_message_t *message, dns_db_t *cache, dns_dbnode_t *node,
-	       dns_rdatatype_t covers, isc_stdtime_t now, dns_ttl_t minttl,
-	       dns_ttl_t maxttl, dns_rdataset_t *addedrdataset) {
-	return (addoptout(message, cache, node, covers, now, minttl, maxttl,
+	       dns_rdatatype_t covers, isc_stdtime_t now, dns_ttl_t maxttl,
+	       dns_rdataset_t *addedrdataset)
+{
+	return (addoptout(message, cache, node, covers, now, maxttl,
 			  false, false, addedrdataset));
 }
 
 isc_result_t
 dns_ncache_addoptout(dns_message_t *message, dns_db_t *cache,
 		     dns_dbnode_t *node, dns_rdatatype_t covers,
-		     isc_stdtime_t now, dns_ttl_t minttl, dns_ttl_t maxttl,
-		     bool optout, dns_rdataset_t *addedrdataset) {
-	return (addoptout(message, cache, node, covers, now, minttl, maxttl,
+		     isc_stdtime_t now, dns_ttl_t maxttl,
+		     bool optout, dns_rdataset_t *addedrdataset)
+{
+	return (addoptout(message, cache, node, covers, now, maxttl,
 			  optout, true, addedrdataset));
 }
 
 static isc_result_t
 addoptout(dns_message_t *message, dns_db_t *cache, dns_dbnode_t *node,
-	  dns_rdatatype_t covers, isc_stdtime_t now, dns_ttl_t minttl,
-	  dns_ttl_t maxttl, bool optout, bool secure,
-	  dns_rdataset_t *addedrdataset) {
+	  dns_rdatatype_t covers, isc_stdtime_t now, dns_ttl_t maxttl,
+	  bool optout, bool secure,
+	  dns_rdataset_t *addedrdataset)
+{
 	isc_result_t result;
 	isc_buffer_t buffer;
 	isc_region_t r;
@@ -158,74 +158,60 @@ addoptout(dns_message_t *message, dns_db_t *cache, dns_dbnode_t *node,
 	ttl = maxttl;
 	trust = 0xffff;
 	isc_buffer_init(&buffer, data, sizeof(data));
-	if (message->counts[DNS_SECTION_AUTHORITY]) {
+	if (message->counts[DNS_SECTION_AUTHORITY])
 		result = dns_message_firstname(message, DNS_SECTION_AUTHORITY);
-	} else {
+	else
 		result = ISC_R_NOMORE;
-	}
 	while (result == ISC_R_SUCCESS) {
 		name = NULL;
-		dns_message_currentname(message, DNS_SECTION_AUTHORITY, &name);
-		if (name->attributes.ncache) {
+		dns_message_currentname(message, DNS_SECTION_AUTHORITY,
+					&name);
+		if ((name->attributes & DNS_NAMEATTR_NCACHE) != 0) {
 			for (rdataset = ISC_LIST_HEAD(name->list);
 			     rdataset != NULL;
-			     rdataset = ISC_LIST_NEXT(rdataset, link))
-			{
+			     rdataset = ISC_LIST_NEXT(rdataset, link)) {
 				if ((rdataset->attributes &
 				     DNS_RDATASETATTR_NCACHE) == 0)
-				{
 					continue;
-				}
 				type = rdataset->type;
-				if (type == dns_rdatatype_rrsig) {
+				if (type == dns_rdatatype_rrsig)
 					type = rdataset->covers;
-				}
 				if (type == dns_rdatatype_soa ||
 				    type == dns_rdatatype_nsec ||
-				    type == dns_rdatatype_nsec3)
-				{
-					if (ttl > rdataset->ttl) {
+				    type == dns_rdatatype_nsec3) {
+					if (ttl > rdataset->ttl)
 						ttl = rdataset->ttl;
-					}
-					if (ttl < minttl) {
-						ttl = minttl;
-					}
-					if (trust > rdataset->trust) {
+					if (trust > rdataset->trust)
 						trust = rdataset->trust;
-					}
 					/*
 					 * Copy the owner name to the buffer.
 					 */
 					dns_name_toregion(name, &r);
 					result = isc_buffer_copyregion(&buffer,
 								       &r);
-					if (result != ISC_R_SUCCESS) {
+					if (result != ISC_R_SUCCESS)
 						return (result);
-					}
 					/*
 					 * Copy the type to the buffer.
 					 */
-					isc_buffer_availableregion(&buffer, &r);
-					if (r.length < 3) {
+					isc_buffer_availableregion(&buffer,
+								   &r);
+					if (r.length < 3)
 						return (ISC_R_NOSPACE);
-					}
 					isc_buffer_putuint16(&buffer,
 							     rdataset->type);
-					isc_buffer_putuint8(
-						&buffer,
-						(unsigned char)rdataset->trust);
+					isc_buffer_putuint8(&buffer,
+					       (unsigned char)rdataset->trust);
 					/*
 					 * Copy the rdataset into the buffer.
 					 */
 					result = copy_rdataset(rdataset,
 							       &buffer);
-					if (result != ISC_R_SUCCESS) {
+					if (result != ISC_R_SUCCESS)
 						return (result);
-					}
 
-					if (next >= DNS_NCACHE_RDATA) {
+					if (next >= DNS_NCACHE_RDATA)
 						return (ISC_R_NOSPACE);
-					}
 					dns_rdata_init(&rdata[next]);
 					isc_buffer_remainingregion(&buffer, &r);
 					rdata[next].data = r.base;
@@ -243,22 +229,19 @@ addoptout(dns_message_t *message, dns_db_t *cache, dns_dbnode_t *node,
 		}
 		result = dns_message_nextname(message, DNS_SECTION_AUTHORITY);
 	}
-	if (result != ISC_R_NOMORE) {
+	if (result != ISC_R_NOMORE)
 		return (result);
-	}
 
 	if (trust == 0xffff) {
 		if ((message->flags & DNS_MESSAGEFLAG_AA) != 0 &&
-		    message->counts[DNS_SECTION_ANSWER] == 0)
-		{
+		    message->counts[DNS_SECTION_ANSWER] == 0) {
 			/*
 			 * The response has aa set and we haven't followed
 			 * any CNAME or DNAME chains.
 			 */
 			trust = dns_trust_authauthority;
-		} else {
+		} else
 			trust = dns_trust_additional;
-		}
 		ttl = 0;
 	}
 
@@ -267,27 +250,26 @@ addoptout(dns_message_t *message, dns_db_t *cache, dns_dbnode_t *node,
 	ncrdatalist.ttl = ttl;
 
 	dns_rdataset_init(&ncrdataset);
-	dns_rdatalist_tordataset(&ncrdatalist, &ncrdataset);
-	if (!secure && trust > dns_trust_answer) {
+	RUNTIME_CHECK(dns_rdatalist_tordataset(&ncrdatalist, &ncrdataset)
+		      == ISC_R_SUCCESS);
+	if (!secure && trust > dns_trust_answer)
 		trust = dns_trust_answer;
-	}
 	ncrdataset.trust = trust;
 	ncrdataset.attributes |= DNS_RDATASETATTR_NEGATIVE;
-	if (message->rcode == dns_rcode_nxdomain) {
+	if (message->rcode == dns_rcode_nxdomain)
 		ncrdataset.attributes |= DNS_RDATASETATTR_NXDOMAIN;
-	}
-	if (optout) {
+	if (optout)
 		ncrdataset.attributes |= DNS_RDATASETATTR_OPTOUT;
-	}
 
-	return (dns_db_addrdataset(cache, node, NULL, now, &ncrdataset, 0,
-				   addedrdataset));
+	return (dns_db_addrdataset(cache, node, NULL, now, &ncrdataset,
+				   0, addedrdataset));
 }
 
 isc_result_t
 dns_ncache_towire(dns_rdataset_t *rdataset, dns_compress_t *cctx,
 		  isc_buffer_t *target, unsigned int options,
-		  unsigned int *countp) {
+		  unsigned int *countp)
+{
 	dns_rdata_t rdata = DNS_RDATA_INIT;
 	isc_result_t result;
 	isc_region_t remaining, tavailable;
@@ -344,18 +326,15 @@ dns_ncache_towire(dns_rdataset_t *rdataset, dns_compress_t *cctx,
 
 			if ((options & DNS_NCACHETOWIRE_OMITDNSSEC) != 0 &&
 			    dns_rdatatype_isdnssec(type))
-			{
 				continue;
-			}
 
 			/*
 			 * Write the name.
 			 */
-			dns_compress_setpermitted(cctx, true);
-			result = dns_name_towire(&name, cctx, target, NULL);
-			if (result != ISC_R_SUCCESS) {
+			dns_compress_setmethods(cctx, DNS_COMPRESS_GLOBAL14);
+			result = dns_name_towire(&name, cctx, target);
+			if (result != ISC_R_SUCCESS)
 				goto rollback;
-			}
 
 			/*
 			 * See if we have space for type, class, ttl, and
@@ -380,9 +359,8 @@ dns_ncache_towire(dns_rdataset_t *rdataset, dns_compress_t *cctx,
 			 * Write the rdata.
 			 */
 			result = dns_rdata_towire(&rdata, cctx, target);
-			if (result != ISC_R_SUCCESS) {
+			if (result != ISC_R_SUCCESS)
 				goto rollback;
-			}
 
 			/*
 			 * Set the rdata length field to the compressed
@@ -390,9 +368,9 @@ dns_ncache_towire(dns_rdataset_t *rdataset, dns_compress_t *cctx,
 			 */
 			INSIST((target->used >= rdlen.used + 2) &&
 			       (target->used - rdlen.used - 2 < 65536));
-			isc_buffer_putuint16(
-				&rdlen,
-				(uint16_t)(target->used - rdlen.used - 2));
+			isc_buffer_putuint16(&rdlen,
+					     (uint16_t)(target->used -
+							    rdlen.used - 2));
 
 			count++;
 		}
@@ -400,16 +378,16 @@ dns_ncache_towire(dns_rdataset_t *rdataset, dns_compress_t *cctx,
 		result = dns_rdataset_next(rdataset);
 		dns_rdata_reset(&rdata);
 	}
-	if (result != ISC_R_NOMORE) {
+	if (result != ISC_R_NOMORE)
 		goto rollback;
-	}
 
 	*countp = count;
 
 	return (ISC_R_SUCCESS);
 
-rollback:
-	dns_compress_rollback(cctx, savedbuffer.used);
+ rollback:
+	INSIST(savedbuffer.used < 65536);
+	dns_compress_rollback(cctx, (uint16_t)savedbuffer.used);
 	*countp = 0;
 	*target = savedbuffer;
 
@@ -417,27 +395,30 @@ rollback:
 }
 
 static void
-rdataset_disassociate(dns_rdataset_t *rdataset DNS__DB_FLARG) {
+rdataset_disassociate(dns_rdataset_t *rdataset) {
 	UNUSED(rdataset);
 }
 
 static isc_result_t
 rdataset_first(dns_rdataset_t *rdataset) {
-	unsigned char *raw;
+	unsigned char *raw = rdataset->private3;
 	unsigned int count;
 
-	raw = rdataset->ncache.raw;
 	count = raw[0] * 256 + raw[1];
 	if (count == 0) {
-		rdataset->ncache.iter_pos = NULL;
+		rdataset->private5 = NULL;
 		return (ISC_R_NOMORE);
 	}
+	raw += 2;
 	/*
-	 * iter_count is the number of rdata beyond the cursor position,
-	 * so we decrement the total count by one before storing it.
+	 * The privateuint4 field is the number of rdata beyond the cursor
+	 * position, so we decrement the total count by one before storing
+	 * it.
 	 */
-	rdataset->ncache.iter_pos = raw + 2;
-	rdataset->ncache.iter_count = count - 1;
+	count--;
+	rdataset->privateuint4 = count;
+	rdataset->private5 = raw;
+
 	return (ISC_R_SUCCESS);
 }
 
@@ -447,45 +428,48 @@ rdataset_next(dns_rdataset_t *rdataset) {
 	unsigned int length;
 	unsigned char *raw;
 
-	raw = rdataset->ncache.iter_pos;
-	count = rdataset->ncache.iter_count;
-	if (count == 0) {
-		rdataset->ncache.iter_pos = NULL;
+	count = rdataset->privateuint4;
+	if (count == 0)
 		return (ISC_R_NOMORE);
-	}
-
+	count--;
+	rdataset->privateuint4 = count;
+	raw = rdataset->private5;
 	length = raw[0] * 256 + raw[1];
-	rdataset->ncache.iter_pos = raw + 2 + length;
-	rdataset->ncache.iter_count = count - 1;
+	raw += length + 2;
+	rdataset->private5 = raw;
+
 	return (ISC_R_SUCCESS);
 }
 
 static void
 rdataset_current(dns_rdataset_t *rdataset, dns_rdata_t *rdata) {
-	unsigned char *raw;
+	unsigned char *raw = rdataset->private5;
 	isc_region_t r;
 
-	raw = rdataset->ncache.iter_pos;
 	REQUIRE(raw != NULL);
 
 	r.length = raw[0] * 256 + raw[1];
-	r.base = raw + 2;
+	raw += 2;
+	r.base = raw;
 	dns_rdata_fromregion(rdata, rdataset->rdclass, rdataset->type, &r);
 }
 
 static void
-rdataset_clone(dns_rdataset_t *source, dns_rdataset_t *target DNS__DB_FLARG) {
+rdataset_clone(dns_rdataset_t *source, dns_rdataset_t *target) {
 	*target = *source;
-	target->ncache.iter_pos = NULL;
-	target->ncache.iter_count = 0;
+
+	/*
+	 * Reset iterator state.
+	 */
+	target->privateuint4 = 0;
+	target->private5 = NULL;
 }
 
 static unsigned int
 rdataset_count(dns_rdataset_t *rdataset) {
-	unsigned char *raw;
+	unsigned char *raw = rdataset->private3;
 	unsigned int count;
 
-	raw = rdataset->ncache.raw;
 	count = raw[0] * 256 + raw[1];
 
 	return (count);
@@ -493,26 +477,36 @@ rdataset_count(dns_rdataset_t *rdataset) {
 
 static void
 rdataset_settrust(dns_rdataset_t *rdataset, dns_trust_t trust) {
-	unsigned char *raw;
+	unsigned char *raw = rdataset->private3;
 
-	raw = rdataset->ncache.raw;
 	raw[-1] = (unsigned char)trust;
-	rdataset->trust = trust;
 }
 
 static dns_rdatasetmethods_t rdataset_methods = {
-	.disassociate = rdataset_disassociate,
-	.first = rdataset_first,
-	.next = rdataset_next,
-	.current = rdataset_current,
-	.clone = rdataset_clone,
-	.count = rdataset_count,
-	.settrust = rdataset_settrust,
+	rdataset_disassociate,
+	rdataset_first,
+	rdataset_next,
+	rdataset_current,
+	rdataset_clone,
+	rdataset_count,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	rdataset_settrust,
+	NULL,
+	NULL,
+	NULL,
+	NULL
 };
 
 isc_result_t
 dns_ncache_getrdataset(dns_rdataset_t *ncacherdataset, dns_name_t *name,
-		       dns_rdatatype_t type, dns_rdataset_t *rdataset) {
+		       dns_rdatatype_t type, dns_rdataset_t *rdataset)
+{
 	isc_result_t result;
 	dns_rdata_t rdata = DNS_RDATA_INIT;
 	isc_region_t remaining;
@@ -523,7 +517,6 @@ dns_ncache_getrdataset(dns_rdataset_t *ncacherdataset, dns_name_t *name,
 	dns_rdataset_t rclone;
 
 	REQUIRE(ncacherdataset != NULL);
-	REQUIRE(DNS_RDATASET_VALID(ncacherdataset));
 	REQUIRE(ncacherdataset->type == 0);
 	REQUIRE((ncacherdataset->attributes & DNS_RDATASETATTR_NEGATIVE) != 0);
 	REQUIRE(name != NULL);
@@ -557,12 +550,10 @@ dns_ncache_getrdataset(dns_rdataset_t *ncacherdataset, dns_name_t *name,
 		dns_rdata_reset(&rdata);
 	}
 	dns_rdataset_disassociate(&rclone);
-	if (result == ISC_R_NOMORE) {
+	if (result == ISC_R_NOMORE)
 		return (ISC_R_NOTFOUND);
-	}
-	if (result != ISC_R_SUCCESS) {
+	if (result != ISC_R_SUCCESS)
 		return (result);
-	}
 
 	INSIST(remaining.length != 0);
 
@@ -572,16 +563,24 @@ dns_ncache_getrdataset(dns_rdataset_t *ncacherdataset, dns_name_t *name,
 	rdataset->covers = 0;
 	rdataset->ttl = ncacherdataset->ttl;
 	rdataset->trust = trust;
-	rdataset->ncache.raw = remaining.base;
-	rdataset->ncache.iter_pos = NULL;
-	rdataset->ncache.iter_count = 0;
+	rdataset->private1 = NULL;
+	rdataset->private2 = NULL;
 
+	rdataset->private3 = remaining.base;
+
+	/*
+	 * Reset iterator state.
+	 */
+	rdataset->privateuint4 = 0;
+	rdataset->private5 = NULL;
+	rdataset->private6 = NULL;
 	return (ISC_R_SUCCESS);
 }
 
 isc_result_t
 dns_ncache_getsigrdataset(dns_rdataset_t *ncacherdataset, dns_name_t *name,
-			  dns_rdatatype_t covers, dns_rdataset_t *rdataset) {
+			  dns_rdatatype_t covers, dns_rdataset_t *rdataset)
+{
 	dns_name_t tname;
 	dns_rdata_rrsig_t rrsig;
 	dns_rdata_t rdata = DNS_RDATA_INIT;
@@ -619,8 +618,7 @@ dns_ncache_getsigrdataset(dns_rdataset_t *ncacherdataset, dns_name_t *name,
 		isc_region_consume(&remaining, 2);
 
 		if (type != dns_rdatatype_rrsig ||
-		    !dns_name_equal(&tname, name))
-		{
+		    !dns_name_equal(&tname, name)) {
 			result = dns_rdataset_next(&rclone);
 			dns_rdata_reset(&rdata);
 			continue;
@@ -651,12 +649,10 @@ dns_ncache_getsigrdataset(dns_rdataset_t *ncacherdataset, dns_name_t *name,
 		dns_rdata_reset(&rdata);
 	}
 	dns_rdataset_disassociate(&rclone);
-	if (result == ISC_R_NOMORE) {
+	if (result == ISC_R_NOMORE)
 		return (ISC_R_NOTFOUND);
-	}
-	if (result != ISC_R_SUCCESS) {
+	if (result != ISC_R_SUCCESS)
 		return (result);
-	}
 
 	INSIST(remaining.length != 0);
 
@@ -666,22 +662,30 @@ dns_ncache_getsigrdataset(dns_rdataset_t *ncacherdataset, dns_name_t *name,
 	rdataset->covers = covers;
 	rdataset->ttl = ncacherdataset->ttl;
 	rdataset->trust = trust;
-	rdataset->ncache.raw = remaining.base;
-	rdataset->ncache.iter_pos = NULL;
-	rdataset->ncache.iter_count = 0;
+	rdataset->private1 = NULL;
+	rdataset->private2 = NULL;
 
+	rdataset->private3 = remaining.base;
+
+	/*
+	 * Reset iterator state.
+	 */
+	rdataset->privateuint4 = 0;
+	rdataset->private5 = NULL;
+	rdataset->private6 = NULL;
 	return (ISC_R_SUCCESS);
 }
 
 void
 dns_ncache_current(dns_rdataset_t *ncacherdataset, dns_name_t *found,
-		   dns_rdataset_t *rdataset) {
+		   dns_rdataset_t *rdataset)
+{
 	dns_rdata_t rdata = DNS_RDATA_INIT;
 	dns_trust_t trust;
 	isc_region_t remaining, sigregion;
 	isc_buffer_t source;
 	dns_name_t tname;
-	dns_rdatatype_t type, covers;
+	dns_rdatatype_t type;
 	unsigned int count;
 	dns_rdata_rrsig_t rrsig;
 	unsigned char *raw;
@@ -709,7 +713,9 @@ dns_ncache_current(dns_rdataset_t *ncacherdataset, dns_name_t *found,
 	INSIST(trust <= dns_trust_ultimate);
 	isc_buffer_remainingregion(&source, &remaining);
 
-	covers = 0;
+	rdataset->methods = &rdataset_methods;
+	rdataset->rdclass = ncacherdataset->rdclass;
+	rdataset->type = type;
 	if (type == dns_rdatatype_rrsig) {
 		/*
 		 * Extract covers from RRSIG.
@@ -722,19 +728,23 @@ dns_ncache_current(dns_rdataset_t *ncacherdataset, dns_name_t *found,
 		raw += 2;
 		sigregion.base = raw;
 		dns_rdata_reset(&rdata);
-		dns_rdata_fromregion(&rdata, ncacherdataset->rdclass, type,
-				     &sigregion);
+		dns_rdata_fromregion(&rdata, rdataset->rdclass,
+				     rdataset->type, &sigregion);
 		(void)dns_rdata_tostruct(&rdata, &rrsig, NULL);
-		covers = rrsig.covered;
-	}
-
-	rdataset->methods = &rdataset_methods;
-	rdataset->rdclass = ncacherdataset->rdclass;
-	rdataset->type = type;
-	rdataset->covers = covers;
+		rdataset->covers = rrsig.covered;
+	} else
+		rdataset->covers = 0;
 	rdataset->ttl = ncacherdataset->ttl;
 	rdataset->trust = trust;
-	rdataset->ncache.raw = remaining.base;
-	rdataset->ncache.iter_pos = NULL;
-	rdataset->ncache.iter_count = 0;
+	rdataset->private1 = NULL;
+	rdataset->private2 = NULL;
+
+	rdataset->private3 = remaining.base;
+
+	/*
+	 * Reset iterator state.
+	 */
+	rdataset->privateuint4 = 0;
+	rdataset->private5 = NULL;
+	rdataset->private6 = NULL;
 }
