@@ -1,17 +1,12 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
 #include <config.h>
@@ -19,6 +14,8 @@
 #if defined(PKCS11CRYPTO) && \
     defined(HAVE_PKCS11_ED25519) || defined(HAVE_PKCS11_ED448)
 
+#include <stdbool.h>
+
 #include <isc/entropy.h>
 #include <isc/mem.h>
 #include <isc/safe.h>
@@ -81,7 +78,7 @@ pkcs11eddsa_createctx(dst_key_t *key, dst_context_t *dctx) {
 		dctx->key->key_alg == DST_ALG_ED448);
 
 	result = isc_buffer_allocate(dctx->mctx, &buf, 16);
-	isc_buffer_setautorealloc(buf, ISC_TRUE);
+	isc_buffer_setautorealloc(buf, true);
 	dctx->ctxdata.generic = buf;
 
 	return (result);
@@ -173,7 +170,7 @@ pkcs11eddsa_sign(dst_context_t *dctx, isc_buffer_t *sig) {
 		slotid = ec->slot;
 	else
 		slotid = pk11_get_best_token(OP_EC);
-	ret = pk11_get_session(pk11_ctx, OP_EC, ISC_TRUE, ISC_FALSE,
+	ret = pk11_get_session(pk11_ctx, OP_EC, true, false,
 			       ec->reqlogon, NULL, slotid);
 	if (ret != ISC_R_SUCCESS)
 		goto err;
@@ -214,7 +211,7 @@ pkcs11eddsa_sign(dst_context_t *dctx, isc_buffer_t *sig) {
 			break;
 		}
 	pk11_ctx->object = CK_INVALID_HANDLE;
-	pk11_ctx->ontoken = ISC_FALSE;
+	pk11_ctx->ontoken = false;
 	PK11_RET(pkcs_C_CreateObject,
 		 (pk11_ctx->session,
 		  keyTemplate, (CK_ULONG) 7,
@@ -299,7 +296,7 @@ pkcs11eddsa_verify(dst_context_t *dctx, const isc_region_t *sig) {
 		slotid = ec->slot;
 	else
 		slotid = pk11_get_best_token(OP_EC);
-	ret = pk11_get_session(pk11_ctx, OP_EC, ISC_TRUE, ISC_FALSE,
+	ret = pk11_get_session(pk11_ctx, OP_EC, true, false,
 			       ec->reqlogon, NULL, slotid);
 	if (ret != ISC_R_SUCCESS)
 		goto err;
@@ -330,7 +327,7 @@ pkcs11eddsa_verify(dst_context_t *dctx, const isc_region_t *sig) {
 			break;
 		}
 	pk11_ctx->object = CK_INVALID_HANDLE;
-	pk11_ctx->ontoken = ISC_FALSE;
+	pk11_ctx->ontoken = false;
 	PK11_RET(pkcs_C_CreateObject,
 		 (pk11_ctx->session,
 		  keyTemplate, (CK_ULONG) 7,
@@ -370,7 +367,7 @@ pkcs11eddsa_verify(dst_context_t *dctx, const isc_region_t *sig) {
 	return (ret);
 }
 
-static isc_boolean_t
+static bool
 pkcs11eddsa_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	pk11_object_t *ec1, *ec2;
 	CK_ATTRIBUTE *attr1, *attr2;
@@ -379,29 +376,29 @@ pkcs11eddsa_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	ec2 = key2->keydata.pkey;
 
 	if ((ec1 == NULL) && (ec2 == NULL))
-		return (ISC_TRUE);
+		return (true);
 	else if ((ec1 == NULL) || (ec2 == NULL))
-		return (ISC_FALSE);
+		return (false);
 
 	attr1 = pk11_attribute_bytype(ec1, CKA_EC_PARAMS);
 	attr2 = pk11_attribute_bytype(ec2, CKA_EC_PARAMS);
 	if ((attr1 == NULL) && (attr2 == NULL))
-		return (ISC_TRUE);
+		return (true);
 	else if ((attr1 == NULL) || (attr2 == NULL) ||
 		 (attr1->ulValueLen != attr2->ulValueLen) ||
 		 !isc_safe_memequal(attr1->pValue, attr2->pValue,
 				    attr1->ulValueLen))
-		return (ISC_FALSE);
+		return (false);
 
 	attr1 = pk11_attribute_bytype(ec1, CKA_EC_POINT);
 	attr2 = pk11_attribute_bytype(ec2, CKA_EC_POINT);
 	if ((attr1 == NULL) && (attr2 == NULL))
-		return (ISC_TRUE);
+		return (true);
 	else if ((attr1 == NULL) || (attr2 == NULL) ||
 		 (attr1->ulValueLen != attr2->ulValueLen) ||
 		 !isc_safe_memequal(attr1->pValue, attr2->pValue,
 				    attr1->ulValueLen))
-		return (ISC_FALSE);
+		return (false);
 
 	attr1 = pk11_attribute_bytype(ec1, CKA_VALUE);
 	attr2 = pk11_attribute_bytype(ec2, CKA_VALUE);
@@ -410,15 +407,15 @@ pkcs11eddsa_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	     (attr1->ulValueLen != attr2->ulValueLen) ||
 	     !isc_safe_memequal(attr1->pValue, attr2->pValue,
 				attr1->ulValueLen)))
-		return (ISC_FALSE);
+		return (false);
 
 	if (!ec1->ontoken && !ec2->ontoken)
-		return (ISC_TRUE);
+		return (true);
 	else if (ec1->ontoken || ec2->ontoken ||
 		 (ec1->object != ec2->object))
-		return (ISC_FALSE);
+		return (false);
 
-	return (ISC_TRUE);
+	return (true);
 }
 
 #define SETCURVE() \
@@ -489,8 +486,8 @@ pkcs11eddsa_generate(dst_key_t *key, int unused, void (*callback)(int)) {
 						  sizeof(*pk11_ctx));
 	if (pk11_ctx == NULL)
 		return (ISC_R_NOMEMORY);
-	ret = pk11_get_session(pk11_ctx, OP_EC, ISC_TRUE, ISC_FALSE,
-			       ISC_FALSE, NULL, pk11_get_best_token(OP_EC));
+	ret = pk11_get_session(pk11_ctx, OP_EC, true, false,
+			       false, NULL, pk11_get_best_token(OP_EC));
 	if (ret != ISC_R_SUCCESS)
 		goto err;
 
@@ -577,15 +574,15 @@ pkcs11eddsa_generate(dst_key_t *key, int unused, void (*callback)(int)) {
 	return (ret);
 }
 
-static isc_boolean_t
+static bool
 pkcs11eddsa_isprivate(const dst_key_t *key) {
 	pk11_object_t *ec = key->keydata.pkey;
 	CK_ATTRIBUTE *attr;
 
 	if (ec == NULL)
-		return (ISC_FALSE);
+		return (false);
 	attr = pk11_attribute_bytype(ec, CKA_VALUE);
-	return (ISC_TF((attr != NULL) || ec->ontoken));
+	return (attr != NULL || ec->ontoken);
 }
 
 static void
@@ -816,8 +813,8 @@ pkcs11eddsa_fetch(dst_key_t *key, const char *engine, const char *label,
 	pubec = pub->keydata.pkey;
 
 	ec->object = CK_INVALID_HANDLE;
-	ec->ontoken = ISC_TRUE;
-	ec->reqlogon = ISC_TRUE;
+	ec->ontoken = true;
+	ec->reqlogon = true;
 	ec->repr = (CK_ATTRIBUTE *) isc_mem_get(key->mctx, sizeof(*attr) * 2);
 	if (ec->repr == NULL)
 		return (ISC_R_NOMEMORY);
@@ -850,7 +847,7 @@ pkcs11eddsa_fetch(dst_key_t *key, const char *engine, const char *label,
 						  sizeof(*pk11_ctx));
 	if (pk11_ctx == NULL)
 		DST_RET(ISC_R_NOMEMORY);
-	ret = pk11_get_session(pk11_ctx, OP_EC, ISC_TRUE, ISC_FALSE,
+	ret = pk11_get_session(pk11_ctx, OP_EC, true, false,
 			       ec->reqlogon, NULL, ec->slot);
 	if (ret != ISC_R_SUCCESS)
 		goto err;
@@ -1042,8 +1039,8 @@ pkcs11eddsa_fromlabel(dst_key_t *key, const char *engine, const char *label,
 		return (ISC_R_NOMEMORY);
 	memset(ec, 0, sizeof(*ec));
 	ec->object = CK_INVALID_HANDLE;
-	ec->ontoken = ISC_TRUE;
-	ec->reqlogon = ISC_TRUE;
+	ec->ontoken = true;
+	ec->reqlogon = true;
 	key->keydata.pkey = ec;
 
 	ec->repr = (CK_ATTRIBUTE *) isc_mem_get(key->mctx, sizeof(*attr) * 2);
@@ -1063,7 +1060,7 @@ pkcs11eddsa_fromlabel(dst_key_t *key, const char *engine, const char *label,
 						  sizeof(*pk11_ctx));
 	if (pk11_ctx == NULL)
 		DST_RET(ISC_R_NOMEMORY);
-	ret = pk11_get_session(pk11_ctx, OP_EC, ISC_TRUE, ISC_FALSE,
+	ret = pk11_get_session(pk11_ctx, OP_EC, true, false,
 			       ec->reqlogon, NULL, ec->slot);
 	if (ret != ISC_R_SUCCESS)
 		goto err;
