@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -28,7 +28,7 @@ fromtext_cname(ARGS_FROMTEXT) {
 	UNUSED(callbacks);
 
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      ISC_FALSE));
+				      false));
 
 	dns_name_init(&name, NULL);
 	buffer_fromregion(&buffer, &token.value.as_region);
@@ -43,7 +43,7 @@ totext_cname(ARGS_TOTEXT) {
 	isc_region_t region;
 	dns_name_t name;
 	dns_name_t prefix;
-	isc_boolean_t sub;
+	bool sub;
 
 	REQUIRE(rdata->type == dns_rdatatype_cname);
 	REQUIRE(rdata->length != 0);
@@ -119,13 +119,15 @@ compare_cname(ARGS_COMPARE) {
 
 static inline isc_result_t
 fromstruct_cname(ARGS_FROMSTRUCT) {
-	dns_rdata_cname_t *cname = source;
+	dns_rdata_cname_t *cname;
 	isc_region_t region;
 
 	REQUIRE(type == dns_rdatatype_cname);
-	REQUIRE(source != NULL);
-	REQUIRE(cname->common.rdtype == type);
-	REQUIRE(cname->common.rdclass == rdclass);
+	REQUIRE(((dns_rdata_cname_t *)source) != NULL);
+	REQUIRE(((dns_rdata_cname_t *)source)->common.rdtype == type);
+	REQUIRE(((dns_rdata_cname_t *)source)->common.rdclass == rdclass);
+
+	cname = source;
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -137,13 +139,15 @@ fromstruct_cname(ARGS_FROMSTRUCT) {
 static inline isc_result_t
 tostruct_cname(ARGS_TOSTRUCT) {
 	isc_region_t region;
-	dns_rdata_cname_t *cname = target;
+	dns_rdata_cname_t *cname;
 	dns_name_t name;
 
+	REQUIRE(((dns_rdata_cname_t *)target) != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_cname);
-	REQUIRE(target != NULL);
 	REQUIRE(rdata->length != 0);
 
+	cname = target;
+
 	cname->common.rdclass = rdata->rdclass;
 	cname->common.rdtype = rdata->type;
 	ISC_LINK_INIT(&cname->common, link);
@@ -159,9 +163,11 @@ tostruct_cname(ARGS_TOSTRUCT) {
 
 static inline void
 freestruct_cname(ARGS_FREESTRUCT) {
-	dns_rdata_cname_t *cname = source;
+	dns_rdata_cname_t *cname;
 
-	REQUIRE(source != NULL);
+	REQUIRE(((dns_rdata_cname_t *)source) != NULL);
+
+	cname = source;
 
 	if (cname->mctx == NULL)
 		return;
@@ -195,7 +201,7 @@ digest_cname(ARGS_DIGEST) {
 	return (dns_name_digest(&name, digest, arg));
 }
 
-static inline isc_boolean_t
+static inline bool
 checkowner_cname(ARGS_CHECKOWNER) {
 
 	REQUIRE(type == dns_rdatatype_cname);
@@ -205,10 +211,10 @@ checkowner_cname(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (ISC_TRUE);
+	return (true);
 }
 
-static inline isc_boolean_t
+static inline bool
 checknames_cname(ARGS_CHECKNAMES) {
 
 	REQUIRE(rdata->type == dns_rdatatype_cname);
@@ -217,7 +223,7 @@ checknames_cname(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (ISC_TRUE);
+	return (true);
 }
 
 static inline int
