@@ -3,28 +3,27 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
  */
 
-#ifndef RDATA_GENERIC_L32_105_C
-#define RDATA_GENERIC_L32_105_C
+#ifndef RDATA_GENERIC_L64_106_C
+#define RDATA_GENERIC_L64_106_C
 
 #include <string.h>
 
 #include <isc/net.h>
 
-#define RRTYPE_L32_ATTRIBUTES (0)
+#define RRTYPE_L64_ATTRIBUTES (0)
 
 static inline isc_result_t
-fromtext_l32(ARGS_FROMTEXT) {
+fromtext_l64(ARGS_FROMTEXT) {
 	isc_token_t token;
-	struct in_addr addr;
-	isc_region_t region;
+	unsigned char locator[NS_LOCATORSZ];
 
-	REQUIRE(type == dns_rdatatype_l32);
+	REQUIRE(type == dns_rdatatype_l64);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -41,24 +40,19 @@ fromtext_l32(ARGS_FROMTEXT) {
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
 				      false));
 
-	if (getquad(DNS_AS_STR(token), &addr, lexer, callbacks) != 1)
-		RETTOK(DNS_R_BADDOTTEDQUAD);
-	isc_buffer_availableregion(target, &region);
-	if (region.length < 4)
-		return (ISC_R_NOSPACE);
-	memmove(region.base, &addr, 4);
-	isc_buffer_add(target, 4);
-	return (ISC_R_SUCCESS);
+	if (locator_pton(DNS_AS_STR(token), locator) != 1)
+		RETTOK(DNS_R_SYNTAX);
+	return (mem_tobuffer(target, locator, NS_LOCATORSZ));
 }
 
 static inline isc_result_t
-totext_l32(ARGS_TOTEXT) {
+totext_l64(ARGS_TOTEXT) {
 	isc_region_t region;
-	char buf[sizeof("65000")];
+	char buf[sizeof("xxxx:xxxx:xxxx:xxxx")];
 	unsigned short num;
 
-	REQUIRE(rdata->type == dns_rdatatype_l32);
-	REQUIRE(rdata->length == 6);
+	REQUIRE(rdata->type == dns_rdatatype_l64);
+	REQUIRE(rdata->length == 10);
 
 	UNUSED(tctx);
 
@@ -70,14 +64,19 @@ totext_l32(ARGS_TOTEXT) {
 
 	RETERR(str_totext(" ", target));
 
-	return (inet_totext(AF_INET, tctx->flags, &region, target));
+	snprintf(buf, sizeof(buf), "%x:%x:%x:%x",
+		 region.base[0]<<8 | region.base[1],
+		 region.base[2]<<8 | region.base[3],
+		 region.base[4]<<8 | region.base[5],
+		 region.base[6]<<8 | region.base[7]);
+	return (str_totext(buf, target));
 }
 
 static inline isc_result_t
-fromwire_l32(ARGS_FROMWIRE) {
+fromwire_l64(ARGS_FROMWIRE) {
 	isc_region_t sregion;
 
-	REQUIRE(type == dns_rdatatype_l32);
+	REQUIRE(type == dns_rdatatype_l64);
 
 	UNUSED(type);
 	UNUSED(options);
@@ -85,17 +84,17 @@ fromwire_l32(ARGS_FROMWIRE) {
 	UNUSED(dctx);
 
 	isc_buffer_activeregion(source, &sregion);
-	if (sregion.length != 6)
+	if (sregion.length != 10)
 		return (DNS_R_FORMERR);
 	isc_buffer_forward(source, sregion.length);
 	return (mem_tobuffer(target, sregion.base, sregion.length));
 }
 
 static inline isc_result_t
-towire_l32(ARGS_TOWIRE) {
+towire_l64(ARGS_TOWIRE) {
 
-	REQUIRE(rdata->type == dns_rdatatype_l32);
-	REQUIRE(rdata->length == 6);
+	REQUIRE(rdata->type == dns_rdatatype_l64);
+	REQUIRE(rdata->length == 10);
 
 	UNUSED(cctx);
 
@@ -103,15 +102,15 @@ towire_l32(ARGS_TOWIRE) {
 }
 
 static inline int
-compare_l32(ARGS_COMPARE) {
+compare_l64(ARGS_COMPARE) {
 	isc_region_t region1;
 	isc_region_t region2;
 
 	REQUIRE(rdata1->type == rdata2->type);
 	REQUIRE(rdata1->rdclass == rdata2->rdclass);
-	REQUIRE(rdata1->type == dns_rdatatype_l32);
-	REQUIRE(rdata1->length == 6);
-	REQUIRE(rdata2->length == 6);
+	REQUIRE(rdata1->type == dns_rdatatype_l64);
+	REQUIRE(rdata1->length == 10);
+	REQUIRE(rdata2->length == 10);
 
 	dns_rdata_toregion(rdata1, &region1);
 	dns_rdata_toregion(rdata2, &region2);
@@ -119,64 +118,60 @@ compare_l32(ARGS_COMPARE) {
 }
 
 static inline isc_result_t
-fromstruct_l32(ARGS_FROMSTRUCT) {
-	dns_rdata_l32_t *l32;
-	uint32_t n;
+fromstruct_l64(ARGS_FROMSTRUCT) {
+	dns_rdata_l64_t *l64;
 
-	REQUIRE(type == dns_rdatatype_l32);
-	REQUIRE(((dns_rdata_l32_t *)source) != NULL);
-	REQUIRE(((dns_rdata_l32_t *)source)->common.rdtype == type);
-	REQUIRE(((dns_rdata_l32_t *)source)->common.rdclass == rdclass);
+	REQUIRE(type == dns_rdatatype_l64);
+	REQUIRE(((dns_rdata_l64_t *)source) != NULL);
+	REQUIRE(((dns_rdata_l64_t *)source)->common.rdtype == type);
+	REQUIRE(((dns_rdata_l64_t *)source)->common.rdclass == rdclass);
 
-	l32 = source;
+	l64 = source;
 
 	UNUSED(type);
 	UNUSED(rdclass);
 
-	RETERR(uint16_tobuffer(l32->pref, target));
-	n = ntohl(l32->l32.s_addr);
-	return (uint32_tobuffer(n, target));
+	RETERR(uint16_tobuffer(l64->pref, target));
+	return (mem_tobuffer(target, l64->l64, sizeof(l64->l64)));
 }
 
 static inline isc_result_t
-tostruct_l32(ARGS_TOSTRUCT) {
+tostruct_l64(ARGS_TOSTRUCT) {
 	isc_region_t region;
-	dns_rdata_l32_t *l32;
-	uint32_t n;
+	dns_rdata_l64_t *l64;
 
-	REQUIRE(((dns_rdata_l32_t *)target) != NULL);
-	REQUIRE(rdata->type == dns_rdatatype_l32);
-	REQUIRE(rdata->length == 6);
+	REQUIRE(((dns_rdata_l64_t *)target) != NULL);
+	REQUIRE(rdata->type == dns_rdatatype_l64);
+	REQUIRE(rdata->length == 10);
 
-	l32 = target;
+	l64 = target;
 
 	UNUSED(mctx);
 
-	l32->common.rdclass = rdata->rdclass;
-	l32->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&l32->common, link);
+	l64->common.rdclass = rdata->rdclass;
+	l64->common.rdtype = rdata->type;
+	ISC_LINK_INIT(&l64->common, link);
 
 	dns_rdata_toregion(rdata, &region);
-	l32->pref = uint16_fromregion(&region);
-	n = uint32_fromregion(&region);
-	l32->l32.s_addr = htonl(n);
+	l64->pref = uint16_fromregion(&region);
+	memmove(l64->l64, region.base, region.length);
 	return (ISC_R_SUCCESS);
 }
 
 static inline void
-freestruct_l32(ARGS_FREESTRUCT) {
-	REQUIRE(((dns_rdata_l32_t *)source) != NULL);
-	REQUIRE(((dns_rdata_l32_t *)source)->common.rdtype ==
-		dns_rdatatype_l32);
+freestruct_l64(ARGS_FREESTRUCT) {
+	REQUIRE(((dns_rdata_l64_t *)source) != NULL);
+	REQUIRE(((dns_rdata_l64_t *)source)->common.rdtype ==
+		dns_rdatatype_l64);
 
 	return;
 }
 
 static inline isc_result_t
-additionaldata_l32(ARGS_ADDLDATA) {
+additionaldata_l64(ARGS_ADDLDATA) {
 
-	REQUIRE(rdata->type == dns_rdatatype_l32);
-	REQUIRE(rdata->length == 6);
+	REQUIRE(rdata->type == dns_rdatatype_l64);
+	REQUIRE(rdata->length == 10);
 
 	UNUSED(rdata);
 	UNUSED(add);
@@ -186,11 +181,11 @@ additionaldata_l32(ARGS_ADDLDATA) {
 }
 
 static inline isc_result_t
-digest_l32(ARGS_DIGEST) {
+digest_l64(ARGS_DIGEST) {
 	isc_region_t r;
 
-	REQUIRE(rdata->type == dns_rdatatype_l32);
-	REQUIRE(rdata->length == 6);
+	REQUIRE(rdata->type == dns_rdatatype_l64);
+	REQUIRE(rdata->length == 10);
 
 	dns_rdata_toregion(rdata, &r);
 
@@ -198,9 +193,9 @@ digest_l32(ARGS_DIGEST) {
 }
 
 static inline bool
-checkowner_l32(ARGS_CHECKOWNER) {
+checkowner_l64(ARGS_CHECKOWNER) {
 
-	REQUIRE(type == dns_rdatatype_l32);
+	REQUIRE(type == dns_rdatatype_l64);
 
 	UNUSED(name);
 	UNUSED(type);
@@ -211,10 +206,10 @@ checkowner_l32(ARGS_CHECKOWNER) {
 }
 
 static inline bool
-checknames_l32(ARGS_CHECKNAMES) {
+checknames_l64(ARGS_CHECKNAMES) {
 
-	REQUIRE(rdata->type == dns_rdatatype_l32);
-	REQUIRE(rdata->length == 6);
+	REQUIRE(rdata->type == dns_rdatatype_l64);
+	REQUIRE(rdata->length == 10);
 
 	UNUSED(rdata);
 	UNUSED(owner);
@@ -224,8 +219,8 @@ checknames_l32(ARGS_CHECKNAMES) {
 }
 
 static inline int
-casecompare_l32(ARGS_COMPARE) {
-	return (compare_l32(rdata1, rdata2));
+casecompare_l64(ARGS_COMPARE) {
+	return (compare_l64(rdata1, rdata2));
 }
 
-#endif	/* RDATA_GENERIC_L32_105_C */
+#endif	/* RDATA_GENERIC_L64_106_C */
