@@ -1,8 +1,6 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * SPDX-License-Identifier: MPL-2.0
- *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at https://mozilla.org/MPL/2.0/.
@@ -28,23 +26,19 @@ check_mx(isc_token_t *token) {
 	struct in_addr addr;
 	struct in6_addr addr6;
 
-	if (strlcpy(tmp, DNS_AS_STR(*token), sizeof(tmp)) >= sizeof(tmp)) {
+	if (strlcpy(tmp, DNS_AS_STR(*token), sizeof(tmp)) >= sizeof(tmp))
 		return (true);
-	}
 
-	if (tmp[strlen(tmp) - 1] == '.') {
+	if (tmp[strlen(tmp) - 1] == '.')
 		tmp[strlen(tmp) - 1] = '\0';
-	}
-	if (inet_pton(AF_INET, tmp, &addr) == 1 ||
+	if (inet_aton(tmp, &addr) == 1 ||
 	    inet_pton(AF_INET6, tmp, &addr6) == 1)
-	{
 		return (false);
-	}
 
 	return (true);
 }
 
-static isc_result_t
+static inline isc_result_t
 fromtext_mx(ARGS_FROMTEXT) {
 	isc_token_t token;
 	dns_name_t name;
@@ -58,50 +52,42 @@ fromtext_mx(ARGS_FROMTEXT) {
 
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
 				      false));
-	if (token.value.as_ulong > 0xffffU) {
+	if (token.value.as_ulong > 0xffffU)
 		RETTOK(ISC_R_RANGE);
-	}
 	RETERR(uint16_tobuffer(token.value.as_ulong, target));
 
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
 				      false));
 
 	ok = true;
-	if ((options & DNS_RDATA_CHECKMX) != 0) {
+	if ((options & DNS_RDATA_CHECKMX) != 0)
 		ok = check_mx(&token);
-	}
-	if (!ok && (options & DNS_RDATA_CHECKMXFAIL) != 0) {
+	if (!ok && (options & DNS_RDATA_CHECKMXFAIL) != 0)
 		RETTOK(DNS_R_MXISADDRESS);
-	}
-	if (!ok && callbacks != NULL) {
+	if (!ok && callbacks != NULL)
 		warn_badmx(&token, lexer, callbacks);
-	}
 
 	dns_name_init(&name, NULL);
 	buffer_fromregion(&buffer, &token.value.as_region);
-	if (origin == NULL) {
+	if (origin == NULL)
 		origin = dns_rootname;
-	}
 	RETTOK(dns_name_fromtext(&name, &buffer, origin, options, target));
 	ok = true;
-	if ((options & DNS_RDATA_CHECKNAMES) != 0) {
+	if ((options & DNS_RDATA_CHECKNAMES) != 0)
 		ok = dns_name_ishostname(&name, false);
-	}
-	if (!ok && (options & DNS_RDATA_CHECKNAMESFAIL) != 0) {
+	if (!ok && (options & DNS_RDATA_CHECKNAMESFAIL) != 0)
 		RETTOK(DNS_R_BADNAME);
-	}
-	if (!ok && callbacks != NULL) {
+	if (!ok && callbacks != NULL)
 		warn_badname(&name, lexer, callbacks);
-	}
 	return (ISC_R_SUCCESS);
 }
 
-static isc_result_t
+static inline isc_result_t
 totext_mx(ARGS_TOTEXT) {
 	isc_region_t region;
 	dns_name_t name;
 	dns_name_t prefix;
-	unsigned int opts;
+	bool sub;
 	char buf[sizeof("64000")];
 	unsigned short num;
 
@@ -120,12 +106,11 @@ totext_mx(ARGS_TOTEXT) {
 	RETERR(str_totext(" ", target));
 
 	dns_name_fromregion(&name, &region);
-	opts = name_prefix(&name, tctx->origin, &prefix) ? DNS_NAME_OMITFINALDOT
-							 : 0;
-	return (dns_name_totext(&prefix, opts, target));
+	sub = name_prefix(&name, tctx->origin, &prefix);
+	return (dns_name_totext(&prefix, sub, target));
 }
 
-static isc_result_t
+static inline isc_result_t
 fromwire_mx(ARGS_FROMWIRE) {
 	dns_name_t name;
 	isc_region_t sregion;
@@ -135,20 +120,19 @@ fromwire_mx(ARGS_FROMWIRE) {
 	UNUSED(type);
 	UNUSED(rdclass);
 
-	dctx = dns_decompress_setpermitted(dctx, true);
+	dns_decompress_setmethods(dctx, DNS_COMPRESS_GLOBAL14);
 
 	dns_name_init(&name, NULL);
 
 	isc_buffer_activeregion(source, &sregion);
-	if (sregion.length < 2) {
+	if (sregion.length < 2)
 		return (ISC_R_UNEXPECTEDEND);
-	}
 	RETERR(mem_tobuffer(target, sregion.base, 2));
 	isc_buffer_forward(source, 2);
-	return (dns_name_fromwire(&name, source, dctx, target));
+	return (dns_name_fromwire(&name, source, dctx, options, target));
 }
 
-static isc_result_t
+static inline isc_result_t
 towire_mx(ARGS_TOWIRE) {
 	dns_name_t name;
 	dns_offsets_t offsets;
@@ -157,7 +141,7 @@ towire_mx(ARGS_TOWIRE) {
 	REQUIRE(rdata->type == dns_rdatatype_mx);
 	REQUIRE(rdata->length != 0);
 
-	dns_compress_setpermitted(cctx, true);
+	dns_compress_setmethods(cctx, DNS_COMPRESS_GLOBAL14);
 
 	dns_rdata_toregion(rdata, &region);
 	RETERR(mem_tobuffer(target, region.base, 2));
@@ -166,10 +150,10 @@ towire_mx(ARGS_TOWIRE) {
 	dns_name_init(&name, offsets);
 	dns_name_fromregion(&name, &region);
 
-	return (dns_name_towire(&name, cctx, target, NULL));
+	return (dns_name_towire(&name, cctx, target));
 }
 
-static int
+static inline int
 compare_mx(ARGS_COMPARE) {
 	dns_name_t name1;
 	dns_name_t name2;
@@ -184,9 +168,8 @@ compare_mx(ARGS_COMPARE) {
 	REQUIRE(rdata2->length != 0);
 
 	order = memcmp(rdata1->data, rdata2->data, 2);
-	if (order != 0) {
+	if (order != 0)
 		return (order < 0 ? -1 : 1);
-	}
 
 	dns_name_init(&name1, NULL);
 	dns_name_init(&name2, NULL);
@@ -203,15 +186,17 @@ compare_mx(ARGS_COMPARE) {
 	return (dns_name_rdatacompare(&name1, &name2));
 }
 
-static isc_result_t
+static inline isc_result_t
 fromstruct_mx(ARGS_FROMSTRUCT) {
-	dns_rdata_mx_t *mx = source;
+	dns_rdata_mx_t *mx;
 	isc_region_t region;
 
 	REQUIRE(type == dns_rdatatype_mx);
-	REQUIRE(mx != NULL);
-	REQUIRE(mx->common.rdtype == type);
-	REQUIRE(mx->common.rdclass == rdclass);
+	REQUIRE(((dns_rdata_mx_t *)source) != NULL);
+	REQUIRE(((dns_rdata_mx_t *)source)->common.rdtype == type);
+	REQUIRE(((dns_rdata_mx_t *)source)->common.rdclass == rdclass);
+
+	mx = source;
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -221,16 +206,18 @@ fromstruct_mx(ARGS_FROMSTRUCT) {
 	return (isc_buffer_copyregion(target, &region));
 }
 
-static isc_result_t
+static inline isc_result_t
 tostruct_mx(ARGS_TOSTRUCT) {
 	isc_region_t region;
-	dns_rdata_mx_t *mx = target;
+	dns_rdata_mx_t *mx;
 	dns_name_t name;
 
+	REQUIRE(((dns_rdata_mx_t *)target) != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_mx);
-	REQUIRE(mx != NULL);
 	REQUIRE(rdata->length != 0);
 
+	mx = target;
+
 	mx->common.rdclass = rdata->rdclass;
 	mx->common.rdtype = rdata->type;
 	ISC_LINK_INIT(&mx->common, link);
@@ -241,21 +228,22 @@ tostruct_mx(ARGS_TOSTRUCT) {
 	isc_region_consume(&region, 2);
 	dns_name_fromregion(&name, &region);
 	dns_name_init(&mx->mx, NULL);
-	name_duporclone(&name, mctx, &mx->mx);
+	RETERR(name_duporclone(&name, mctx, &mx->mx));
 	mx->mctx = mctx;
 	return (ISC_R_SUCCESS);
 }
 
-static void
+static inline void
 freestruct_mx(ARGS_FREESTRUCT) {
-	dns_rdata_mx_t *mx = source;
+	dns_rdata_mx_t *mx;
 
-	REQUIRE(mx != NULL);
-	REQUIRE(mx->common.rdtype == dns_rdatatype_mx);
+	REQUIRE(((dns_rdata_mx_t *)source) != NULL);
+	REQUIRE(((dns_rdata_mx_t *)source)->common.rdtype == dns_rdatatype_mx);
 
-	if (mx->mctx == NULL) {
+	mx = source;
+
+	if (mx->mctx == NULL)
 		return;
-	}
 
 	dns_name_free(&mx->mx, mx->mctx);
 	mx->mctx = NULL;
@@ -263,10 +251,10 @@ freestruct_mx(ARGS_FREESTRUCT) {
 
 static unsigned char port25_offset[] = { 0, 3 };
 static unsigned char port25_ndata[] = "\003_25\004_tcp";
-static dns_name_t port25 = DNS_NAME_INITNONABSOLUTE(port25_ndata,
-						    port25_offset);
+static dns_name_t port25 =
+	 DNS_NAME_INITNONABSOLUTE(port25_ndata, port25_offset);
 
-static isc_result_t
+static inline isc_result_t
 additionaldata_mx(ARGS_ADDLDATA) {
 	isc_result_t result;
 	dns_fixedname_t fixed;
@@ -276,34 +264,28 @@ additionaldata_mx(ARGS_ADDLDATA) {
 
 	REQUIRE(rdata->type == dns_rdatatype_mx);
 
-	UNUSED(owner);
-
 	dns_name_init(&name, offsets);
 	dns_rdata_toregion(rdata, &region);
 	isc_region_consume(&region, 2);
 	dns_name_fromregion(&name, &region);
 
-	if (dns_name_equal(&name, dns_rootname)) {
+	if (dns_name_equal(&name, dns_rootname))
 		return (ISC_R_SUCCESS);
-	}
 
-	result = (add)(arg, &name, dns_rdatatype_a, NULL DNS__DB_FILELINE);
-	if (result != ISC_R_SUCCESS) {
+	result = (add)(arg, &name, dns_rdatatype_a);
+	if (result != ISC_R_SUCCESS)
 		return (result);
-	}
 
 	dns_fixedname_init(&fixed);
 	result = dns_name_concatenate(&port25, &name,
 				      dns_fixedname_name(&fixed), NULL);
-	if (result != ISC_R_SUCCESS) {
+	if (result != ISC_R_SUCCESS)
 		return (ISC_R_SUCCESS);
-	}
 
-	return ((add)(arg, dns_fixedname_name(&fixed), dns_rdatatype_tlsa,
-		      NULL DNS__DB_FILELINE));
+	return ((add)(arg, dns_fixedname_name(&fixed), dns_rdatatype_tlsa));
 }
 
-static isc_result_t
+static inline isc_result_t
 digest_mx(ARGS_DIGEST) {
 	isc_region_t r1, r2;
 	dns_name_t name;
@@ -320,8 +302,9 @@ digest_mx(ARGS_DIGEST) {
 	return (dns_name_digest(&name, digest, arg));
 }
 
-static bool
+static inline bool
 checkowner_mx(ARGS_CHECKOWNER) {
+
 	REQUIRE(type == dns_rdatatype_mx);
 
 	UNUSED(type);
@@ -330,7 +313,7 @@ checkowner_mx(ARGS_CHECKOWNER) {
 	return (dns_name_ishostname(name, wildcard));
 }
 
-static bool
+static inline bool
 checknames_mx(ARGS_CHECKNAMES) {
 	isc_region_t region;
 	dns_name_t name;
@@ -344,17 +327,16 @@ checknames_mx(ARGS_CHECKNAMES) {
 	dns_name_init(&name, NULL);
 	dns_name_fromregion(&name, &region);
 	if (!dns_name_ishostname(&name, false)) {
-		if (bad != NULL) {
+		if (bad != NULL)
 			dns_name_clone(&name, bad);
-		}
 		return (false);
 	}
 	return (true);
 }
 
-static int
+static inline int
 casecompare_mx(ARGS_COMPARE) {
 	return (compare_mx(rdata1, rdata2));
 }
 
-#endif /* RDATA_GENERIC_MX_15_C */
+#endif	/* RDATA_GENERIC_MX_15_C */
