@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -17,9 +17,10 @@
 #include <stddef.h>
 #include <setjmp.h>
 
+#include <sched.h> /* IWYU pragma: keep */
 #include <stdbool.h>
-#include <stdlib.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 
@@ -138,8 +139,8 @@ dns_acl_isinsecure_test(void **state) {
 	de->type = dns_aclelementtype_geoip;
 	de->negative = false;
 	assert_true(geoip->length < geoip->alloc);
-	geoip->node_count++;
-	de->node_num = geoip->node_count;
+	dns_acl_node_count(geoip)++;
+	de->node_num = dns_acl_node_count(geoip);
 	geoip->length++;
 
 	result = dns_acl_create(mctx, 1, &notgeoip);
