@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -903,7 +903,7 @@ remove_nodes(dns_rbt_t *mytree, char **names,
 
 	UNUSED(mytree);
 
-	for (i = 0; i < num_names; i++) {
+	for (i = 0; i < num_names && *names_count > 0; i++) {
 		uint32_t node;
 		dns_fixedname_t fname;
 		dns_name_t *name;
@@ -920,6 +920,7 @@ remove_nodes(dns_rbt_t *mytree, char **names,
 		assert_int_equal(result, ISC_R_SUCCESS);
 
 		isc_mem_free(mctx, names[node]);
+
 		if (*names_count > 0) {
 			names[node] = names[*names_count - 1];
 			names[*names_count - 1] = NULL;
@@ -972,6 +973,7 @@ rbt_insert_and_remove(void **state) {
 	char *names[1024];
 	size_t names_count;
 	int i;
+	isc_time_t start, now;
 
 	UNUSED(state);
 
@@ -988,8 +990,11 @@ rbt_insert_and_remove(void **state) {
 	memset(names, 0, sizeof(names));
 	names_count = 0;
 
-	/* Repeat the insert/remove test some 4096 times */
-	for (i = 0; i < 4096; i++) {
+	/* Repeat the insert/remove test for some 4096 times or 180 seconds. */
+	result = isc_time_now(&start);
+	assert_int_equal(result, ISC_R_SUCCESS);
+	now = start;
+	for (i = 0; i < 4096 && isc_time_microdiff(&now, &start) < 180000000; i++) {
 		uint32_t num_names;
 		isc_random_get(&num_names);
 
@@ -1013,6 +1018,8 @@ rbt_insert_and_remove(void **state) {
 
 		remove_nodes(mytree, names, &names_count, num_names);
 		check_tree(mytree, names, names_count);
+		result = isc_time_now(&now);
+		assert_int_equal(result, ISC_R_SUCCESS);
 	}
 
 	/* Remove the rest of the nodes */
