@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -93,10 +93,9 @@ isc_ht_destroy(isc_ht_t **htp) {
 	size_t i;
 
 	REQUIRE(htp != NULL);
+	REQUIRE(ISC_HT_VALID((*htp)));
 
 	ht = *htp;
-	REQUIRE(ISC_HT_VALID(ht));
-
 	ht->magic = 0;
 
 	for (i = 0; i < ht->size; i++) {
@@ -169,7 +168,9 @@ isc_ht_find(const isc_ht_t *ht, const unsigned char *key,
 	while (node != NULL) {
 		if (keysize == node->keysize &&
 		    memcmp(key, node->key, keysize) == 0) {
-			*valuep = node->value;
+			if (valuep != NULL) {
+				*valuep = node->value;
+			}
 			return (ISC_R_SUCCESS);
 		}
 		node = node->next;
