@@ -1,8 +1,6 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * SPDX-License-Identifier: MPL-2.0
- *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at https://mozilla.org/MPL/2.0/.
@@ -11,45 +9,43 @@
  * information regarding copyright ownership.
  */
 
-#pragma once
+
+#ifndef ISC_SOCKADDR_H
+#define ISC_SOCKADDR_H 1
 
 /*! \file isc/sockaddr.h */
 
 #include <stdbool.h>
-#include <sys/un.h>
 
-#include <isc/hash.h>
 #include <isc/lang.h>
 #include <isc/net.h>
 #include <isc/types.h>
+#ifdef ISC_PLATFORM_HAVESYSUNH
+#include <sys/un.h>
+#endif
 
-/*
- * Any updates to this structure should also be applied in
- * contrib/modules/dlz/dlz_minmal.h.
- */
 struct isc_sockaddr {
 	union {
 		struct sockaddr		sa;
 		struct sockaddr_in	sin;
 		struct sockaddr_in6	sin6;
 		struct sockaddr_storage ss;
-	} type;
-	unsigned int length; /* XXXRTH beginning? */
-	ISC_LINK(struct isc_sockaddr) link;
+#ifdef ISC_PLATFORM_HAVESYSUNH
+		struct sockaddr_un	sunix;
+#endif
+	}				type;
+	unsigned int			length;		/* XXXRTH beginning? */
+	ISC_LINK(struct isc_sockaddr)	link;
 };
 
-#define ISC_SOCKADDR_CMPADDR            \
-	0x0001 /*%< compare the address \
-		*   sin_addr/sin6_addr */
-#define ISC_SOCKADDR_CMPPORT         \
-	0x0002 /*%< compare the port \
-		*   sin_port/sin6_port */
-#define ISC_SOCKADDR_CMPSCOPE         \
-	0x0004 /*%< compare the scope \
-		*   sin6_scope */
-#define ISC_SOCKADDR_CMPSCOPEZERO         \
-	0x0008 /*%< when comparing scopes \
-		*   zero scopes always match */
+#define ISC_SOCKADDR_CMPADDR	  0x0001	/*%< compare the address
+						 *   sin_addr/sin6_addr */
+#define ISC_SOCKADDR_CMPPORT 	  0x0002	/*%< compare the port
+						 *   sin_port/sin6_port */
+#define ISC_SOCKADDR_CMPSCOPE     0x0004	/*%< compare the scope
+						 *   sin6_scope */
+#define ISC_SOCKADDR_CMPSCOPEZERO 0x0008	/*%< when comparing scopes
+						 *   zero scopes always match */
 
 ISC_LANG_BEGINDECLS
 
@@ -85,16 +81,7 @@ isc_sockaddr_eqaddrprefix(const isc_sockaddr_t *a, const isc_sockaddr_t *b,
  * If 'b''s scope is zero then 'a''s scope will be ignored.
  */
 
-void
-isc_sockaddr_hash_ex(isc_hash32_t *hash, const isc_sockaddr_t *sockaddr,
-		     bool address_only);
-/*%<
- * Add the hash of the sockaddr into the hash for incremental hashing
- *
- * See isc_sockaddr_hash() for details.
- */
-
-uint32_t
+unsigned int
 isc_sockaddr_hash(const isc_sockaddr_t *sockaddr, bool address_only);
 /*%<
  * Return a hash value for the socket address 'sockaddr'.  If 'address_only'
@@ -233,13 +220,22 @@ isc_sockaddr_isnetzero(const isc_sockaddr_t *sa);
  */
 
 isc_result_t
-isc_sockaddr_fromsockaddr(isc_sockaddr_t *isa, const struct sockaddr *sa);
+isc_sockaddr_frompath(isc_sockaddr_t *sockaddr, const char *path);
+/*
+ *  Create a UNIX domain sockaddr that refers to path.
+ *
+ * Returns:
+ * \li	ISC_R_NOSPACE
+ * \li	ISC_R_NOTIMPLEMENTED
+ * \li	ISC_R_SUCCESS
+ */
 
-#define ISC_SOCKADDR_FORMATSIZE                                            \
-	sizeof("xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:XXX.XXX.XXX.XXX%SSSSSSSSSS#" \
-	       "YYYYY")
+#define ISC_SOCKADDR_FORMATSIZE \
+	sizeof("xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:XXX.XXX.XXX.XXX%SSSSSSSSSS#YYYYY")
 /*%<
  * Minimum size of array to pass to isc_sockaddr_format().
  */
 
 ISC_LANG_ENDDECLS
+
+#endif /* ISC_SOCKADDR_H */
