@@ -18,7 +18,7 @@
 #include <isc/iterated_hash.h>
 
 int
-isc_iterated_hash(unsigned char out[ISC_SHA1_DIGESTLENGTH],
+isc_iterated_hash(unsigned char out[NSEC3_MAX_HASH_LENGTH],
 		  unsigned int hashalg, int iterations,
 		  const unsigned char *salt, int saltlength,
 		  const unsigned char *in, int inlength)
