@@ -3,14 +3,12 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
  */
 
-/* $Id$ */
-
 /*	$FreeBSD: src/sys/crypto/sha2/sha2.c,v 1.2.2.2 2002/03/05 08:36:47 ume Exp $	*/
 /*	$KAME: sha2.c,v 1.8 2001/11/08 01:07:52 itojun Exp $	*/
 
@@ -887,7 +885,7 @@ isc_sha224_update(isc_sha224_t *context, const uint8_t* data, size_t len) {
 }
 
 void
-isc_sha224_final(uint8_t digest[], isc_sha224_t *context) {
+isc_sha224_final(uint8_t digest[ISC_SHA224_DIGESTLENGTH], isc_sha224_t *context) {
 	uint8_t sha256_digest[ISC_SHA256_DIGESTLENGTH];
 	isc_sha256_final(sha256_digest, (isc_sha256_t *)context);
 	memmove(digest, sha256_digest, ISC_SHA224_DIGESTLENGTH);
@@ -1150,7 +1148,7 @@ isc_sha256_update(isc_sha256_t *context, const uint8_t *data, size_t len) {
 }
 
 void
-isc_sha256_final(uint8_t digest[], isc_sha256_t *context) {
+isc_sha256_final(uint8_t digest[ISC_SHA256_DIGESTLENGTH], isc_sha256_t *context) {
 	uint32_t	*d = (uint32_t*)digest;
 	unsigned int	usedspace;
 
@@ -1513,7 +1511,7 @@ void isc_sha512_last(isc_sha512_t *context) {
 	isc_sha512_transform(context, (uint64_t*)context->buffer);
 }
 
-void isc_sha512_final(uint8_t digest[], isc_sha512_t *context) {
+void isc_sha512_final(uint8_t digest[ISC_SHA512_DIGESTLENGTH], isc_sha512_t *context) {
 	uint64_t	*d = (uint64_t*)digest;
 
 	/* Sanity check: */
@@ -1566,7 +1564,7 @@ isc_sha384_update(isc_sha384_t *context, const uint8_t* data, size_t len) {
 }
 
 void
-isc_sha384_final(uint8_t digest[], isc_sha384_t *context) {
+isc_sha384_final(uint8_t digest[ISC_SHA384_DIGESTLENGTH], isc_sha384_t *context) {
 	uint64_t	*d = (uint64_t*)digest;
 
 	/* Sanity check: */
@@ -1603,7 +1601,7 @@ isc_sha384_final(uint8_t digest[], isc_sha384_t *context) {
 static const char *sha2_hex_digits = "0123456789abcdef";
 
 char *
-isc_sha224_end(isc_sha224_t *context, char buffer[]) {
+isc_sha224_end(isc_sha224_t *context, char buffer[ISC_SHA224_DIGESTSTRINGLENGTH]) {
 	uint8_t	digest[ISC_SHA224_DIGESTLENGTH], *d = digest;
 	unsigned int	i;
 
@@ -1644,7 +1642,7 @@ isc_sha224_data(const uint8_t *data, size_t len,
 }
 
 char *
-isc_sha256_end(isc_sha256_t *context, char buffer[]) {
+isc_sha256_end(isc_sha256_t *context, char buffer[ISC_SHA256_DIGESTSTRINGLENGTH]) {
 	uint8_t	digest[ISC_SHA256_DIGESTLENGTH], *d = digest;
 	unsigned int	i;
 
@@ -1685,7 +1683,7 @@ isc_sha256_data(const uint8_t* data, size_t len,
 }
 
 char *
-isc_sha512_end(isc_sha512_t *context, char buffer[]) {
+isc_sha512_end(isc_sha512_t *context, char buffer[ISC_SHA512_DIGESTSTRINGLENGTH]) {
 	uint8_t	digest[ISC_SHA512_DIGESTLENGTH], *d = digest;
 	unsigned int	i;
 
@@ -1726,7 +1724,7 @@ isc_sha512_data(const uint8_t *data, size_t len,
 }
 
 char *
-isc_sha384_end(isc_sha384_t *context, char buffer[]) {
+isc_sha384_end(isc_sha384_t *context, char buffer[ISC_SHA384_DIGESTSTRINGLENGTH]) {
 	uint8_t	digest[ISC_SHA384_DIGESTLENGTH], *d = digest;
 	unsigned int	i;
 
